var skroller;

(function ($, window, _) {
	'use strict';

	var $doc = $(document),
			win = $(window),
			body = $('body'),
			thb_md = new MobileDetect(window.navigator.userAgent);

	window.lazySizesConfig = window.lazySizesConfig || {};
  window.lazySizesConfig.expand = 250;
  window.lazySizesConfig.loadMode = 1;
	window.lazySizesConfig.loadHidden = false;

	var SITE = {
		menuscroll: $('#menu-scroll'),
		init: function() {
			var self = this,
					obj;

			for (obj in self) {
				if ( self.hasOwnProperty(obj)) {
					var _method =  self[obj];
					if ( _method.selector !== undefined && _method.init !== undefined ) {
						if ( $(_method.selector).length > 0 ) {
							_method.init();
						}
					}
				}
			}
		},
		fixedHeader: {
			selector: '.subheader.fixed',
			init: function() {
				var base = this,
						container = $(base.selector);

				win.on('scroll.fixed-header',function(){
					base.scroll(container);
				}).trigger('scroll.fixed-header');
			},
			scroll: function (container) {
				var animationOffset = 400,
						wOffset = win.scrollTop(),
						stick = 'header--slide',
						unstick = 'header--unslide',
						search = container.find('.quick_search');

				if (wOffset > animationOffset) {
					if (container.hasClass(unstick)) {
						container.removeClass(unstick);
					}
					if (!container.hasClass(stick)) {
						setTimeout(function () {
							container.addClass(stick);
						}, 10);
					}
				} else if ((wOffset < animationOffset && (wOffset > 0))) {
					if(container.hasClass(stick)) {
						container.removeClass(stick);
						container.addClass(unstick);
						search.removeClass('active');
					}
				} else {
					container.removeClass(stick);
					container.removeClass(unstick);
					search.removeClass('active');
				}
			}

		},
		search: {
			selector: '.quick_toggle',
			init: function() {
				var base = this,
						container = $(base.selector);

				container.each(function(e) {
					var _this = $(this),
							form = _this.parents('.quick_search');
					_this.on('click', function(e) {
						form.toggleClass('active');
						return false;
					});
				});
			}
		},
		responsiveNav: {
			selector: '#wrapper',
			init: function() {
				var base = this,
					container = $(base.selector),
					cc = $('.click-capture'),
					mm = $('#mobile-menu'),
					span = mm.find('.mobile-menu li:has(".sub-menu")>a span');


				$('.mobile-toggle-holder').on('click', function() {
					container.removeClass('open-menu').addClass('open-menu');
					return false;
				});
				cc.add(mm.find('.thb-close')).on('click', function() {
					container.removeClass('open-menu');
				});

				span.on('click', function(e){
					var that = $(this),
							parent = that.parents('a'),
							menu = parent.next('.sub-menu');

					if (parent.hasClass('active')) {
						parent.removeClass('active');
						menu.slideUp('200', function() {
							setTimeout(function () {
								SITE.menuscroll.update();
							}, 10);
						});
					} else {
						parent.addClass('active');
						menu.slideDown('200', function() {
							setTimeout(function () {
								SITE.menuscroll.update();
							}, 10);
						});
					}
					e.stopPropagation();
					e.preventDefault();
				});

			}
		},
		categoryMenu: {
			selector: '.sf-menu:not(.secondary)',
			init: function() {
				var base = this,
					container = $(base.selector),
					children = container.find('.menu-item-has-children');

				children.each(function() {
					var _this = $(this),
						menu = _this.find('>.sub-menu,>.thb_mega_menu_holder'),
						tabs = _this.find('.thb_mega_menu li'),
						contents = _this.find('.category-children>.row');

					tabs.first().addClass('active');
					_this.hoverIntent(
						function() {
							gsap.to(menu, { duration: 0.5, autoAlpha: 1, ease: Quart.easeOut, onStart: function() { menu.css('display', 'block'); }, onComplete: function() { SITE.circle_perc.control(); } });
						},
						function() {
							gsap.to(menu, { duration: 0.5, autoAlpha: 0, ease: Quart.easeOut, onComplete: function() { menu.css('display', 'none'); }});
						}
					);
					tabs.on('mouseenter', function() {
						var _li = $(this),
								n = _li.index();
						tabs.removeClass('active');
						_li.addClass('active');
						contents.hide();
						contents.filter(':nth-child('+(n+1)+')').css({'display': 'flex'});
						SITE.circle_perc.control();
					});
				});
			}
		},
		secondaryMenu: {
			selector: '.secondary-holder',
			init: function() {
				var base = this,
					container = $(base.selector),
					menu = container.find('.sf-menu'),
					maxWidth = -1;

				$('>li', menu).each(function() {
					maxWidth = maxWidth > $(this).outerWidth() ? maxWidth : $(this).outerWidth();
				});
				menu.css({
					'display': 'none',
					'width': (maxWidth * 2) + 70
				});
				container.hoverIntent(
					function() {
						gsap.to(menu, {duration: 0.5, autoAlpha: 1, ease: Quart.easeOut, onStart: function() { menu.css('display', 'flex'); }});
					},
					function() {
						gsap.to(menu, {duration: 0.5, autoAlpha: 0, ease: Quart.easeOut, onComplete: function() { menu.css('display', 'none'); }});
					}
				);
			}
		},
		loginForm: {
			selector: '#thb-login',
			init: function() {
				var base = this,
						container = $(base.selector),
						login_form = $('#thb_login_form', container),
						register_form = $('#thb_registration_form', container),
						lost_form = $('#thb_lost_form', container),
						ul = $('ul', container),
						links = $('a', ul),
						lost_password = $('.lost_password', container),
						back = $('.back', container);

				links.on('click', function() {
					var _this = $(this);
					if (!_this.hasClass('active')) {
						links.removeClass('active');
						_this.addClass('active');

						$('.thb-form-container', container).toggleClass('register-active');
					}
					return false;
				});
				lost_password.on('click', function() {
					ul.addClass('lost');

					$('.thb-form-container', container).removeClass('register-active');
					$('.thb-form-container', container).addClass('lost-active');

					return false;
				});

				back.on('click', function() {
					ul.removeClass('lost');

					$('.thb-form-container', container).removeClass('lost-active');

					return false;
				});

				/* Lost Password Form */
				lost_form.on('submit', function(e){

					e.preventDefault();

					var button = $(this).find('button'),
							org_text = button.text();
							button.text(themeajax.l10n.loading).addClass('loading');

					$.post(themeajax.url, lost_form.serialize(), function(data){
						var obj = $.parseJSON(data);

						$('.thb-errors.lost-errors').html(obj.message);

						button.text(org_text).removeClass('loading');
					});

				});

				/* Login Form */
				login_form.on('submit', function(e){
					e.preventDefault();

					var button = $(this).find('button'),
							org_text = button.text();
							button.text(themeajax.l10n.loading).addClass('loading');

					$.post(themeajax.url, login_form.serialize(), function(data){
						var obj = $.parseJSON(data);

						$('.thb-errors.login-errors').html(obj.message);

						if(obj.error === false){
							container.addClass('loading');
							window.location.reload(true);
							button.hide();
						} else {
							button.text(org_text).removeClass('loading');
						}
					});

				});

				/* Register Form */
				register_form.on('submit', function(e){
					e.preventDefault();

					var button = $(this).find('button'),
							org_text = button.text();
							button.text(themeajax.l10n.loading).addClass('loading');

					$.post(themeajax.url, register_form.serialize(), function(data){
						var obj = $.parseJSON(data);

						$('.thb-errors.register-errors').html(obj.message);

						if(obj.error === false){
							button.hide();
						} else {
							button.text(org_text).removeClass('loading');
						}
					});

				});
			}
		},
		magnificSingle: {
			selector: '[rel="magnific"]',
			init: function() {
				var base = this,
						container = $(base.selector),
						stype;

				container.each(function() {
					$(this).magnificPopup({
						type: 'image',
						closeOnContentClick: true,
						fixedContentPos: true,
						closeBtnInside: false,
						mainClass: 'mfp-zoom-in',
						removalDelay: 250,
						overflowY: 'scroll',
						image: {
							verticalFit: true,
							titleSrc: function(item) {
								return item.el.attr('title');
							}
						},
						callbacks: {
							imageLoadComplete: function()  {
								var _this = this;
								_.delay( function() { _this.wrap.addClass('mfp-image-loaded'); }, 10);
							},
							beforeOpen: function() {
								this.st.image.markup = this.st.image.markup.replace('mfp-figure', 'mfp-figure mfp-with-anim');
						  }
						}
					});
				});
			}
		},
		magnificImage: {
			selector: '.thb-lightbox-on .blog-post',
			init: function() {
				var base = this,
						container = $(base.selector);

				container.each(function() {
					$(this).magnificPopup({
						delegate: '[rel="mfp"]',
						type: 'image',
						closeOnContentClick: true,
						fixedContentPos: true,
						mainClass: 'mfp-zoom-in',
						removalDelay: 250,
						closeBtnInside: false,
						overflowY: 'scroll',
						gallery: {
							enabled: true,
							navigateByImgClick: false,
							preload: [0,1] // Will preload 0 - before current, and 1 after the current image
						},
						image: {
							verticalFit: true,
							titleSrc: function(item) {
								return item.el.attr('title');
							}
						},
						callbacks: {
							imageLoadComplete: function()  {
								var _this = this;
								_.delay( function() { _this.wrap.addClass('mfp-image-loaded'); }, 10);
							},
							beforeOpen: function() {
						    this.st.image.markup = this.st.image.markup.replace('mfp-figure', 'mfp-figure mfp-with-anim');
						  },
						  open: function() {
						  	$.magnificPopup.instance.next = function() {
						  		var _this = this;
									_this.wrap.removeClass('mfp-image-loaded');

									setTimeout( function() { $.magnificPopup.proto.next.call(_this); }, 125);
								};

								$.magnificPopup.instance.prev = function() {
									var _this = this;
									this.wrap.removeClass('mfp-image-loaded');

									setTimeout( function() { $.magnificPopup.proto.prev.call(_this); }, 125);
								};
						  }
						}
					});
				});

			}
		},
		magnificInline: {
			selector: '[rel="inline"]',
			init: function() {
				var base = this,
						container = $(base.selector);

				container.each(function() {
					var _this = $(this);

					_this.magnificPopup({
						type:'inline',
						midClick: true,
						mainClass: 'mfp-fade thb-inline-lightbox',
						removalDelay: 250,
						closeOnContentClick:false,
						fixedContentPos: true,
						closeBtnInside: true,
						overflowY: 'scroll'
					});
				});

			}
		},
		carousel: {
			selector: '.slick',
			init: function(el) {
				var base = this,
					container = el ? el : $(base.selector);

				container.each(function() {
					var that = $(this),
							columns = that.data('columns'),
							navigation = (that.data('navigation') === true ? true : false),
							autoplay = (that.data('autoplay') === false ? false : true),
							pagination = (that.data('pagination') === true ? true : false),
							speed = (that.data('speed') ? that.data('speed') : 1000),
							center = (that.data('center') ? that.data('center') : false),
							disablepadding = (that.data('disablepadding') ? that.data('disablepadding') : false),
							vertical = (that.data('vertical') ? that.data('vertical') : false),
							fade = (that.data('fade') === true ? true : false),
							centerarrows = that.hasClass('center-arrows'),
							asNavFor = that.data('asnavfor'),
							rtl = body.hasClass('rtl');

					var args = {
						dots: pagination,
						arrows: navigation,
						infinite: true,
						speed: speed,
						centerMode: center,
						slidesToShow: columns,
						slidesToScroll: 1,
						rtl: rtl,
						rows: 0,
						autoplay: autoplay,
						centerPadding: (disablepadding ? 0 : '50px'),
						autoplaySpeed: 6000,
						pauseOnHover: true,
						focusOnSelect: true,
						adaptiveHeight: true,
						vertical: vertical,
						verticalSwiping: vertical,
						accessibility: false,
						fade: fade,
						cssEase: 'ease-in-out',
						prevArrow: '<button type="button" class="slick-nav slick-prev"><i class="fa fa-angle-left"></i></button>',
						nextArrow: '<button type="button" class="slick-nav slick-next"><i class="fa fa-angle-right"></i></button>',
						responsive: [
							{
								breakpoint: 1025,
								settings: {
									slidesToShow: (columns < 3 ? columns : (vertical ? columns-1 :3)),
									centerPadding: (disablepadding ? 0 : '40px')
								}
							},
							{
								breakpoint: 780,
								settings: {
									slidesToShow: (columns < 2 ? columns : (vertical ? columns-1 :2)),
									centerPadding: (disablepadding ? 0 : '30px')
								}
							},
							{
								breakpoint: 640,
								settings: {
									slidesToShow: (columns < 2 ? columns : (vertical ? columns-1 :1)),
									centerPadding: (disablepadding ? 0 : '15px')
								}
							}
						]
					};
					if (asNavFor && $(asNavFor).is(':visible')) {
						args.asNavFor = asNavFor;
					}
					if (that.hasClass('product-images') || that.data('fade')) {
						args.fade = true;
					}
					if (that.hasClass('carousel-slider')) {
						args.responsive = [
							{
								breakpoint: 1025,
								settings: {
									slidesToShow: (columns < 3 ? columns : (vertical ? columns-1 :3))
								}
							},
							{
								breakpoint: 780,
								settings: {
									slidesToShow: (columns < 2 ? columns : (vertical ? columns-1 :2))
								}
							},
							{
								breakpoint: 640,
								settings: {
									slidesToShow: (columns < 2 ? columns : (vertical ? columns-1 :1))
								}
							}
						];
					}
					that.on('init', function() {
						SITE.circle_perc.control();

						if (centerarrows) {
							win.trigger('resize.position_arrows');
						}
					});
					if ( centerarrows ) {
						win.on('resize.position_arrows', function() {
							var g = that.find('.post-gallery').length ? that.find('.post-gallery') : that.find('.thb-placeholder'),
									h = Math.round(g.outerHeight() / 2);
							that.find('.slick-nav').css({'top': h});
						});
					}
					that.on('afterChange', function(event, slick, currentSlide, nextSlide){
						SITE.circle_perc.control();
					});
					if (that.hasClass('post-slider-style4')) {
						args.dotsClass = 'post-title-bullets';
						args.customPaging = function(slick, i) {
							var slide = $(slick.$slides[i]),
									meta = slide.find('.post-category').text(),
									title = slide.find('h1').text();
							return $('<button type="button" class="post" />').html('<span>0' + ( i + 1 ) + '</span><aside class="post-category single_category_title">'+ meta + '</aside><h6>'+ title+ '</h6>');

						};
						args.responsive[0].settings.dots = false;
						args.responsive[1].settings.dots = false;
						args.responsive[2].settings.dots = false;

						if (that.parents('.full-width-row').length) {
							that.on('setPosition', function() {
								var active = that.find('.slick-active .row.max_width'),
										right = (win.width() - (active.offset().left + active.outerWidth())) + 15;
								that.find('.post-title-bullets').css('right', right + 'px');
							});
						}
					}
					if (that.hasClass('video-thumbnail-slider')) {
						args.responsive[2].settings.slidesToShow = 2;
					}
					that.slick(args);
					that.find('.wp-post-image').on('lazyloaded', function() {
						if (centerarrows) {
							win.trigger('resize.position_arrows');
						}
					});
					if (that.parents('.vc_tta-container').length) {
						$(document).on("click.vc.tabs.data-api", function() {
							that.slick('refresh');
						});
					}
				});
			}
		},
		cookieBar: {
			selector: '.thb-cookie-bar',
			init: function() {
				var base = this,
						container = $(base.selector),
						button = $('.button', container);

				if (Cookies.get('thb-goodlife-cookiebar') !== 'hide') {
					gsap.to(container, { duration: 0.5, opacity: '1', y: '0%' });
				}
				button.on('click', function() {
				  Cookies.set('thb-goodlife-cookiebar', 'hide', { expires: 30 });
				 	gsap.to(container, { duration: 0.5, opacity: '0', y: '100%' });
					return false;
				});
			}
		},
		paginationStyle2: {
			selector: '.pagination-style2',
			init: function() {
				var base = this,
						container = $(base.selector);

				container.each(function() {
					var _this = $(this),
							security = _this.data('security'),
							page = 2,
							loadmore = $(_this.data('loadmore')),
							rand = _this.data('rand'),
							text = loadmore.text(),
							thb_endpoint = ('thb_postajax_'+rand),
							loop = window[thb_endpoint].loop,
							style = window[thb_endpoint].style,
							columns = window[thb_endpoint].columns,
							excerpts = window[thb_endpoint].excerpts,
							count = window[thb_endpoint].count;

					if (loadmore.length > 0) {
						loadmore.on('click', function() {
							loadmore.text(themeajax.l10n.loading);
							$.post( themeajax.url, {
								action: 'thb_posts',
								security: security,
                count: count,
								loop: loop,
								page: page,
								columns: columns,
								style: style,
								excerpts : excerpts,
							}, function(data){

								page++;
								var d = $.parseHTML($.trim(data)),
										l = d ? d.length : 0;

								if ( data === '' || data === 'undefined' || data === 'No More Posts' || data === 'No $args array created') {
									data = '';
									loadmore.text(themeajax.l10n.nomore).removeClass('loading').off('click');
								} else {

									$(d).insertBefore(loadmore.parents('.masonry_loader')).hide();
									$(d).show();


									gsap.set($(d), { opacity: 0, y:20 });
									gsap.staggerTo($(d), { duration: 0.25, stagger: 0.15, y: 0, opacity:1, ease: Quart.easeOut });


									if (l < count){
										loadmore.text(themeajax.l10n.nomore).removeClass('loading');
									} else {
										loadmore.text(text).removeClass('loading');
									}
								}
							});
							return false;
						});
					}
				});
			}
		},
		paginationStyle3: {
			selector: '.pagination-style3',
			init: function() {
				var base = this,
						container = $(base.selector);

				container.each(function() {
					var _this = $(this),
							security = _this.data('security'),
							thb_loading = false,
							page = 2,
							rand = _this.data('rand'),
							thb_endpoint = ('thb_postajax_'+rand),
							count = window[thb_endpoint].count,
							style = window[thb_endpoint].style,
							columns = window[thb_endpoint].columns,
							excerpts = window[thb_endpoint].excerpts;

					var scrollFunction = _.debounce(function(){
						if ( ( thb_loading === false ) && ( (win.scrollTop() + win.height() + 150) >= (_this.offset().top + _this.outerHeight()) ) ) {
							$.ajax( themeajax.url, {
								method : 'POST',
								data : {
									action: 'thb_posts',
									security: security,
									count: count,
									style: style,
									excerpts: excerpts,
									page: page,
									columns: columns
								},
								beforeSend: function() {
									_this.addClass('thb-loading-bottom');
									thb_loading = true;
								},
								success : function(data) {
									thb_loading = false;
									page++;
									var d = $.parseHTML($.trim(data)),
											l = d ? d.length : 0;

									if( data === '' || data === 'undefined' || data === 'No More Posts' || data === 'No $args array created') {
										win.off('scroll', scrollFunction);
									} else {

										_this.removeClass('thb-loading-bottom');
										$(d).appendTo(_this).hide();
										$(d).show();
										SITE.circle_perc.init();
										gsap.set($(d), {opacity: 0, y:20});
										gsap.staggerTo($(d), { y: 0, duration: 0.25, stagger: 0.15, opacity:1, ease: Quart.easeOut, onComplete: function() {
											if (l >= count) {
												win.on('scroll', scrollFunction);
											}
										} });
									}
								}
							});
						}
					}, 30);

					win.scroll(scrollFunction);
				});
			}
		},
		galleryArrows: {
			selector: '.blog-post.format-gallery',
			init: function(el) {
				var base = this,
						container = el ? el : $(base.selector);

				$doc.on('keyup', function(e) {
					if (e.keyCode === 37 && container.find('.slick-prev', '.gallery-pagination').length) { // Left
						container.find('.slick-prev', '.gallery-pagination')[0].click();
					}
					if (e.keyCode === 39 && container.find('.slick-next', '.gallery-pagination').length) { // Right
						container.find('.slick-next', '.gallery-pagination')[0].click();
					}
				});
			}
		},
		articleScroll: {
			selector: '#infinite-article',
			org_post_url: window.location.href,
			org_post_title: document.title,
			org_shares: false,
			init: function() {
				var base = this,
						container = $(base.selector),
						security = container.data('security'),
						on = container.data('infinite'),
						count = container.data('infinite-count'),
						org = container.find('.blog-post:first-child'),
						org_shares = org.find('.share-main'),
						id = org.data('id'),
						tempid = id,
						thb_loading = false,
						footer = $('#footer').outerHeight() + $('#subfooter').outerHeight(),
						i = 0;

				var scrollLocation = _.debounce(function(){
						base.location_change();
					}, 10);

				var scrollAjax = _.debounce(function(){
					if (!count || i < parseInt(count, 10)) {
						if (win.scrollTop() >= ($doc.height() - win.height() - footer - 200) && thb_loading === false) {
							container.addClass('thb-loading-bottom');

							if (id === tempid) {
								$.ajax( themeajax.url, {
									method : 'POST',
									data : {
										action : 'thb_infinite_ajax',
										post_id : tempid,
										security: security,
									},
									beforeSend: function() {
										id = null;
										thb_loading = true;
									},
									success : function(data) {
										i++;
										thb_loading = false;
										var d = $.parseHTML(data),
												ads = $(d).find('.adsbygoogle, .adworx_ad'),
												tweets = $(d).find('.twitter-tweet, .twitter-timeline'),
												instagram = $(d).find('.instagram-media');

										container.removeClass('thb-loading-bottom');

										if (d) {
											var the_post = $(d).find('.blog-post');
											id = the_post.data('id');
											tempid = id;

											$(d).appendTo(container);
											SITE.plyr.init();
											SITE.circle_perc.init();
											SITE.carousel.init($(d).find('.slick'));
											SITE.fixedPosition.init($(d).find('.fixed-me'));
											SITE.magnificImage.init();
											SITE.parallax_bg.init();
											SITE.topReviews.init();
											SITE.shareArticleDetail.init();
											SITE.animation.init();

											if (typeof window.instgrm !== 'undefined') {
												window.instgrm.Embeds.process();
											} else if (instagram.length && (typeof window.instgrm === 'undefined')) {
												var ins = document.createElement( 'script' );
												ins.src   = "//platform.instagram.com/en_US/embeds.js";
												ins.onload = function(){
											    window.instgrm.Embeds.process();
											  };
												body.append(ins);
											}

											if (typeof window.twttr !== 'undefined') {
												twttr.widgets.load(
												  document.getElementById("infinite-article")
												);
											} else if (tweets.length && (typeof window.twttr === 'undefined')) {
												window.twttr = (function(d, s, id) {
													var js, fjs = d.getElementsByTagName(s)[0],
													  t = window.twttr || {};
													if (d.getElementById(id)) { return t; }
													js = d.createElement(s);
													js.id = id;
													js.src = "https://platform.twitter.com/widgets.js";
													fjs.parentNode.insertBefore(js, fjs);

													t._e = [];
													t.ready = function(f) {
													  t._e.push(f);
													};
													return t;
												}(document, "script", "twitter-wjs"));
											}

											if (the_post.hasClass('format-gallery')) {
												$doc.off('keyup');
												SITE.galleryArrows.init(the_post);
											}
											if (typeof window.googletag !== 'undefined') {
												googletag.pubads().refresh();
											}
											if (typeof window.addthis !== 'undefined') {
												addthis.toolbox();
											}
											if (typeof window.atnt !== 'undefined') {
												window.atnt();
											}
											if (typeof window.adsbygoogle !== 'undefined' && ads.length) {
												ads.each(function() {
													(adsbygoogle = window.adsbygoogle || []).push({});
												});
											}
											if (typeof window.vc_js !== 'undefined') {
  											window.vc_js();
  										}
											if (typeof (FB) !== 'undefined') {
												FB.init({ status: true, cookie: true, xfbml: true });
											}
											$(document.body).trigger('thb_after_infinite_load');
										} else {
											id = null;
										}
									}
								});
							}
						}
					}
				}, 100);

				if (on === 'on') {
					win.scroll(scrollLocation);
					win.scroll(scrollAjax);
				} else {
					win.scroll(_.debounce(function(){
						base.borderWidth($('.post-detail-row').offset().top, $('.post-detail-row').outerHeight(true));
					}, 10));
				}
			},
			location_change: function() {
				var base = this,
						container = $(base.selector);

				var windowTop           = win.scrollTop(),
						windowBottom        = windowTop + win.height(),
						windowSize          = windowBottom - windowTop,
						setsInView          = [],
						post_title,
						post_url,
						shares;

				$('.post-detail-row').each( function() {
					var _row = $(this),
							post = _row.find('.blog-post'),
							id = post.data( 'id' ),
							setTop = _row.offset().top - ($('.subheader.fixed').outerHeight() + ( $('#wpadminbar').outerHeight() || 0 ) ),
							setHeight = _row.outerHeight(true),
							setBottom = 0,
							tmp_post_url = post.data('url'),
							tmp_post_title	= _row.find('.post-title h1').text(),
							shares = _row.find('.share-main');

					// Determine position of bottom of set by adding its height to the scroll position of its top.
					setBottom = setTop + setHeight;

					if ( setTop < windowTop && setBottom > windowBottom ) { // top of set is above window, bottom is below
						setsInView.push({'id': id, 'top': setTop, 'bottom': setBottom, 'post_url': tmp_post_url, 'post_title': tmp_post_title, 'alength' : setHeight, 'shares' : shares });
					}
					else if( setTop > windowTop && setTop < windowBottom ) { // top of set is between top (gt) and bottom (lt)
						setsInView.push({'id': id, 'top': setTop, 'bottom': setBottom, 'post_url': tmp_post_url, 'post_title': tmp_post_title, 'alength' : setHeight, 'shares' : shares });
					}
					else if( setBottom > windowTop && setBottom < windowBottom ) { // bottom of set is between top (gt) and bottom (lt)
						setsInView.push({'id': id, 'top': setTop, 'bottom': setBottom, 'post_url': tmp_post_url, 'post_title': tmp_post_title, 'alength' : setHeight, 'shares' : shares });
					}
				});

				// Parse number of sets found in view in an attempt to update the URL to match the set that comprises the majority of the window
				if ( 0 === setsInView.length ) {
					post_url = base.org_post_url;
					post_title = base.org_post_title;
					shares = base.org_shares;

				} else if ( 1 === setsInView.length ) {
					var setData = setsInView.pop();

					post_url = setData.post_url;
					post_title = setData.post_title;
					shares = setData.shares;

					base.borderWidth(setData.top, setData.alength);
				} else {
					post_url = setsInView[0].post_url;
					post_title = setsInView[0].post_title;
					shares = setsInView[0].shares;
					base.borderWidth(setsInView[0].top, setsInView[0].alength);
				}

				base.updateURL(post_url, post_title, shares);
			},
			updateURL : function(post_url, post_title, shares) {
				if( window.location.href !== post_url ) {

					if ( post_url !== '' ) {
						history.replaceState( null, null, post_url );
						document.title = post_title;
						$('#page-title').html(post_title);

						if (shares) {
							$('.subheader.fixed').find('.share-article-vertical').html(shares.html());
							SITE.shareArticleDetail.init();
						}
					}
					this.updateGA(post_url);
				}
			},
			updateGA: function(post_url) {
				if( typeof _gaq !== 'undefined' ) {
					_gaq.push(['_trackPageview', post_url]);
				} else if ( typeof ga !== 'undefined' ) {
					var reg = /.+?\:\/\/.+?(\/.+?)(?:#|\?|$)/,
							pathname = reg.exec( post_url )[1];

					ga('send', 'pageview', pathname );
				}
			},
			borderWidth: function(top, setHeight) {
				var windowTop = win.scrollTop(),
						perc = (windowTop - top) / setHeight;

				gsap.set($('.progress', '.subheader.fixed'), { scaleX: perc });
			}
		},
		postGridAjaxify: {
			selector: '.ajaxify-pagination',
			init: function() {
				var base = this,
						container = $(base.selector),
						_this = container;

				// Initialized
				_this.data('initialized', true);
				// Prepare our Variables
				var History = window.History,
						document = window.document;

				// Check to see if History.js is enabled for our Browser
				if ( !History.enabled ) {
					return false;
				}

				var rootUrl = History.getRootUrl();

				// Ajaxify Helper
				$.fn.ajaxify = _.debounce(function(){
					// Prepare
					var $_this = $(this);

					// Ajaxify
					$_this.find('.page-numbers').on('click',function(e){

						// Prepare
						var $_this	= $(this),
								url = $_this.attr('href'),
								title = $_this.attr('title') || null;

						// Continue as normal for cmd clicks etc
						if ( e.which === 2 || e.metaKey ) { return true; }

						// Ajaxify this link
						History.pushState(null,title,url);
						e.preventDefault();
						return false;
					});
					// Chain
					return $_this;
				}, 50);

				// Ajaxify our Internal Links
				_this.ajaxify();

				// Hook into State Changes
				win.bind('statechange',function(){
					// Prepare Variables
					var State = History.getState(),
							url = State.url,
							relativeUrl = url.replace(rootUrl,''),
							a = $('#wpadminbar'),
							ah = a.outerHeight() || 0;

					// Start Fade Out
					// Animating to opacity to 0 still keeps the element's height intact
					// Which prevents that annoying pop bang issue when loading in new content
					// Let's add some cool animation here

					_this.addClass('thb-loading');
					jQuery('html, body').animate({
						scrollTop: _this.offset().top - ah - 30
					}, 800);


					// Ajax Request the Traditional Page
					$.post( url, function(data){
						// Prepare
						var html = $.parseHTML(data),
								title = $(html).filter('title').text(),
								contentHTML = $(html).find('.ajaxify-pagination').html();

						if ( !contentHTML ) {
							document.location.href = url;
							return false;
						}

						// Update the content
						_this.stop(true,true);
						_this.html(contentHTML)
								.ajaxify()
								.animate({'opacity': 1}, 500, 'linear', function() {
									document.title = title;
									_this.removeClass('thb-loading');
									SITE.circle_perc.control();
									$(document.body).trigger("sticky_kit:recalc");
								});

						// Inform Google Analytics of the change
						if ( typeof window.pageTracker !== 'undefined' ) {
							window.pageTracker._trackPageview(relativeUrl);
						}

						// Inform ReInvigorate of a state change
						if ( typeof window.reinvigorate !== 'undefined' && typeof window.reinvigorate.ajax_track !== 'undefined' ) {
							reinvigorate.ajax_track(url);// ^ we use the full url here as that is what reinvigorate supports
						}
					});

				}); // end onStateChange
			}
		},
		circle_perc: {
			selector: '.circle_perc',
			init: function() {
				var base = this,
						container = $(base.selector);

				base.control(container);

				win.on('scroll', function(){
					base.control(container);
				});
			},
			control: function(element) {
				var t = -1,
						control_element = element ? element : $(this.selector);


				control_element.filter(':in-viewport').each(function() {
					var _this = $(this),
							offset = _this.data('dashoffset');
							t++;

					setTimeout(function() {
						gsap.to(_this, { duration: 1, attr:{ "stroke-dashoffset": offset }});
					}, 150 * t);

				});
			}
		},
		newsletter: {
			selector: '.newsletter-form',
			init: function() {
				var base = this,
					container = $(base.selector);

				container.each(function() {
					var _this = $(this),
							security = _this.data('security');
					_this.on('submit', function() {
						$.post(themeajax.url, {
							action: 'thb_subscribe_emails',
							security: security,
							email: _this.find('.widget_subscribe').val(),
						}, function(data) {
							var d = $.parseHTML($.trim(data));
							_this.next('.result').html(d).fadeIn(200).delay(3000).fadeOut(200);
						});
						return false;
					});
				});

			}
		},
		animation: {
			selector: '.animation',
			init: function() {
				var base = this,
						container = $(base.selector);

				$('.animation.bottom-to-top-3d, .animation.top-to-bottom-3d').parent(':not(.slick-track)').addClass('perspective-wrap');

				win.on('scroll.thb-animation', function(){
					base.control(container, true);
				}).trigger('scroll.thb-animation');
			},
			container: function(container) {
				var base = this,
						element = $(base.selector, container);

				base.control(element, false);
			},
			control: function(element, filter) {
				var t = 0,
						delay = 0.15,
						speed = 0.5,
						el = filter ? element.filter(':in-viewport') : element;

				el.each(function() {
					var _this = $(this);

					if (_this.data('thb-animated') !== true ) {
						_this.data('thb-animated', true);
						gsap.to(_this, { duration: speed, autoAlpha: 1, x: 0, y: 0, z:0, rotationZ: '0deg', rotationX: '0deg', rotationY: '0deg', delay: t*delay });
					}

					t++;
				});
			}
		},
		topReviews: {
			selector: '.widget_topreviews .progress, .post-review .progress span',
			init: function() {
				var base = this,
						container = $(base.selector);

				base.control(container);

				win.on('scroll.thb-reviews', function(){
					base.control(container);
				}).trigger('scroll.thb-reviews');
			},
			control: function(element) {
				var t = -1;

				element.filter(':in-viewport').each(function () {
					var _this = $(this),
							progress = _this.data('width');
							t++;
					setTimeout(function () {
						gsap.to(_this, { duration: 1, "width": progress + '%'});
					}, 200 * t);

				});
			}
		},
		plyr: {
			selector: '.flex-video, .wp-video video',
			init: function() {
				var base = this,
					container = $(base.selector),
					custom_player = themeajax.settings.thb_custom_video_player,
					publisher_id = themeajax.settings.viai_publisher_id,
					options = {
						playsinline: true,
						clickToPlay: true,
					};

				if (publisher_id && publisher_id !== '') {
					options.ads = {
						enabled: true,
						publisherId: publisher_id
					};
				}
				if (custom_player === 'on') {
					if (thb_md.mobile() || thb_md.tablet()) {
						return;
					}
					container.each(function() {
						var player = new Plyr($(this), options);
					});
				}
			}
		},
		comments: {
			selector: '.expanded-comments-off #comment-toggle',
			init: function() {
				var base = this,
				container = $(base.selector);

				container.on('click', function() {
					$(this).toggleClass('active');
					$(this).next('.comment-content-container').slideToggle();
					return false;
				});
			}
		},
		videoPlaylist: {
			selector: '.video_playlist',
			init: function() {
				var base = this,
				container = $(base.selector);

				container.each(function() {
					var _this = $(this),
							security = _this.data('security'),
							video_area = _this.find('.video-side'),
							links = _this.find('.video_play');

					container.on('click', '.video_play', function() {
						var _that = $(this),
								id = _that.data('post-id');

						if (_that.hasClass('video-active')) {
							return false;
						}
						_this.find('.video_play').removeClass('video-active');
						_this.find('.video_play[data-post-id="'+id+'"]').addClass('video-active');
						video_area.addClass('thb-loading');

						$.post( themeajax.url, {
							action: 'thb-parse-embed',
							security: security,
							post_ID: id
						}, function(d){
							if (d.success) {
								video_area.html(d.data.body);
								SITE.plyr.init();
							}
							video_area.removeClass('thb-loading');
						});
						return false;
					});
				});
			}
		},
		postListing: {
			selector: '.thb_listing',
			init: function() {
				var base = this,
				container = $(base.selector);

				container.each(function() {
					var that = $(this),
							security = that.data('security'),
							type = that.data('type'),
							count = that.data('count'),
							links = that.find('a'),
							ul = that.parents('.widget_title').next('ul'),
							tl = gsap.timeline();

					links.on('click', function() {
						var _this = $(this),
								time = _this.data('time'),
								prev = ul.find('li,p'),
								prev_l = prev.length;

						ul.addClass('thb-loading');
						$.post( themeajax.url, {
							action: 'thb_listing',
							security: security,
							count: count,
							type: type,
							time: time
						}, function(data){
							var d = $.parseHTML($.trim(data)),
									li = d.length ? $(d).filter(function() {
									        return this.nodeType === 1;
									    }) : false;

							links.removeClass('active');
							_this.addClass('active');
							if ( prev.length ) {
								tl.to(prev, { duration: 0.5, stagger: 0.1, x: -30, opacity:0,
										onStart: function() { ul.removeClass('thb-loading'); },
										onComplete: function() {
											ul.html(li);
										}
									});
								if ( li.length ){
									tl
										.set(li, { x: 30, opacity:0 })
										.to(li, { duration: 0.5, stagger: 0.1, x: 0, opacity:1 });
								}
							}
						});
						return false;
					});
				});
			}
		},
		shareArticleDetail: {
			selector: '.share-article, .share-article-vertical',
			init: function() {
				var base = this,
						container = $(base.selector),
						social = container.find('.social:not(.whatsapp)');


				social.on('click', function() {
					var left = (screen.width/2)-(640/2),
							top = (screen.height/2)-(440/2)-100;
					window.open($(this).attr('href'), 'mywin', 'left='+left+',top='+top+',width=640,height=440,toolbar=0');
					return false;
				});
			}
		},
		custom_scroll: {
			selector: '.custom_scroll',
			init: function() {
				var base = this,
						container = $(base.selector);

				container.each(function() {
					var _this = $(this);

					var ps = new PerfectScrollbar(_this[0], { suppressScrollX: true });

					if (_this.attr('id') === 'menu-scroll') {
						SITE.menuscroll = ps;
					}
				});

			}
		},
		categoryDropdown: {
			selector: '.thb-sibling-categories',
			init: function() {
				var base = this,
						container = $(base.selector);

				container.each(function() {
					var _this = $(this),
							security = _this.data('security'),
							items = _this.find('li:not(.thb-pull-down)'),
							more_container = _this.find('li.thb-pull-down'),
							vertical_container = _this.find('.thb-pull-down .sub-menu'),
							horizontal_width = 0,
							var_items = [],
							content = _this.parents('.category-element-holder').find('.category-element-content');

					more_container.find('>a').on('click', function() {return false;});
					items.each(function() {
						var_items.push({
							'el' : $(this),
							'width' : $(this).outerWidth(true),
							'added' : false
						});
					});
					items.remove();

					base.start(_this, var_items, vertical_container, more_container, content, security);

				});
			},
			start: function(parent, items, vertical_container, more_container, content, security) {
				var cached_items = items;

				_.each(cached_items, function(value, key, list) {
					value.el.find('[data-ajax-cat]').on('click', function() {
						content.addClass('thb-loading-center');
						$.post( themeajax.url, {
							action: 'thb_ajax_cat',
							security: security,
							catid: $(this).data('ajax-cat'),
							style: content.data('style'),
							count: content.data('count')
						}, function(data){
							content.removeClass('thb-loading-center');
							var d = $.parseHTML($.trim(data));

							if( data === '' || data === 'undefined' || data === 'No More Posts' || data === 'No $args array created') {
								data = '';
							} else {
								content.html($(d));

								SITE.circle_perc.control();
							}
						});
						return false;
					});
				});
				parent.addClass('active');
				function setItems() {
					var parent_width = parent.outerWidth(),
							horizontal_width = more_container.outerWidth(true) + 15,
							visible_items = _.filter(cached_items, { 'added': false }),
							hidden_items = _.filter(cached_items, { 'added': true });

					for (var k = 0; k < visible_items.length; k++) {
						horizontal_width += visible_items[k].width;
					}

					if ( horizontal_width >= parent_width) {
						if (_.last(visible_items)) {
							_.last(visible_items).added = true;
						}
					} else if (_.first(hidden_items) ? (_.first(hidden_items).width + horizontal_width < parent_width) : true ){
						if (_.first(hidden_items)) {
							_.first(hidden_items).added = false;
						}
					}
					for (var i = 0; i < visible_items.length; i++) {
						visible_items[i].el.insertBefore(more_container);
					}
					for (var j = 0; j < hidden_items.length; j++) {
						vertical_container.prepend(hidden_items[j].el);
					}
					if (hidden_items.length === 0) {
						more_container.hide();
					} else {
						more_container.css({
							'display': 'inline-block'
						});
					}
				}
				for (var m = 0; m < cached_items.length + 1; m++) {
					setItems();
				}
				win.on('resize', function(){
					setItems();
				});
			}
		},
		parallax_bg: {
			selector: 'body',
			active: 0,
			init: function() {
				var main = $('div[role="main"]');

				if (main.find('.parallax_bg').length > 0) {
					window.skroller = skrollr.init({
						forceHeight: false,
						easing: 'outCubic',
						mobileCheck: function() {
							return false;
						}
					});
				}
			}
		},
		fixedPosition: {
			selector: '.fixed-me',
			init: function(el) {
				var base = this,
					container = el ? el : $(base.selector),
					a = $('#wpadminbar'),
					ah = a.outerHeight() || 0;

				if (!thb_md.mobile()) {
					container.each(function() {
						var _this = $(this),
								off = 27 + ($('.subheader.fixed').length ? 50 : 0);

						_this.stick_in_parent({
							offset_top: off + ah,
							inner_scrolling: false
						});
					});

				}
				$('.post-gallery.vertical').waitForImages(function() {
					$(document.body).trigger("sticky_kit:recalc");
				});
				win.resize(_.debounce(function(){
					$(document.body).trigger("sticky_kit:detach");
				}, 30));
			}
		},
		toTop: {
			selector: '#scroll_totop',
			init: function() {
				var base = this,
						container = $(base.selector);

				container.on('click', function(){
					gsap.to(win, {duration: 0.5, scrollTo: { y: 0, autoKill:false }, ease:Quart.easeOut});
					return false;
				});
				win.scroll(_.debounce(function(){
					base.control();
				}, 50));
			},
			control: function() {
				var base = this,
						container = $(base.selector);

				if (win.scrollTop() > 300) {
					gsap.to(container, { duration: 0.2, autoAlpha:1, ease: Quart.easeOut });
				} else {
					gsap.to(container, { duration: 0.2, autoAlpha:0, ease: Quart.easeOut });
				}
			}
		},
		wpml: {
			selector: '#thb_language_selector_mobile',
			init: function() {
				var base = this,
						container = $(base.selector);

				container.on('change', function () {
				var url = $(this).val(); // get selected value
					if (url) { // require a URL
						window.location = url; // redirect
					}
					return false;
				});
			}
		},
		variations: {
			selector: 'form.variations_form',
			init: function() {
				var base = this,
					container = $(base.selector),
					slider = $('#product-images'),
					thumbnails = $('#product-thumbnails'),
					org_image = $('.first img', slider).attr('src'),
					org_thumb = $('.first img', thumbnails).attr('src');

				container.on("show_variation", function(e, variation) {
					if (variation.hasOwnProperty("image") && variation.image.src) {
						$('.first img', slider).attr("src", variation.image.src).attr("srcset", "");
						$('.first img', thumbnails).attr("src", variation.image.thumb_src).attr("srcset", "");

						if (slider.hasClass('slick-initialized')) {
							slider.slick('slickGoTo', 0);
						}
					}
				}).on('reset_image', function () {
					$('.first img', slider).attr("src", org_image).attr("srcset", "");
					$('.first img', thumbnails).attr("src", org_thumb).attr("srcset", "");
				});
			}
		},
		quantity: {
			selector: '.quantity:not(.hidden)',
			init: function() {
				var base = this,
						container = $(base.selector);

				base.initialize();
				body.on( 'updated_cart_totals', function(){
					base.initialize();
				});
			},
			initialize: function() {
				// Quantity buttons
				$( 'div.quantity:not(.buttons_added), td.quantity:not(.buttons_added)' ).addClass( 'buttons_added' ).append( '<input type="button" value="+" class="plus" />' ).prepend( '<input type="button" value="-" class="minus" />' ).end().find('input[type="number"]').attr('type', 'text');
				$('.plus, .minus').on('click', function() {
					// Get values
					var $qty		= $( this ).closest( '.quantity' ).find( '.qty' ),
						currentVal	= parseFloat( $qty.val() ),
						max			= parseFloat( $qty.attr( 'max' ) ),
						min			= parseFloat( $qty.attr( 'min' ) ),
						step		= $qty.attr( 'step' );

					// Format values
					if ( ! currentVal || currentVal === '' || currentVal === 'NaN' ) { currentVal = 0; }
					if ( max === '' || max === 'NaN' ) { max = ''; }
					if ( min === '' || min === 'NaN' ) { min = 0; }
					if ( step === 'any' || step === '' || step === undefined || parseFloat( step ) === 'NaN' ) { step = 1; }

					// Change the value
					if ( $( this ).is( '.plus' ) ) {

						if ( max && ( max === currentVal || currentVal > max ) ) {
							$qty.val( max );
						} else {
							$qty.val( currentVal + parseFloat( step ) );
						}

					} else {

						if ( min && ( min === currentVal || currentVal < min ) ) {
							$qty.val( min );
						} else if ( currentVal > 0 ) {
							$qty.val( currentVal - parseFloat( step ) );
						}

					}

					// Trigger change event
					$qty.trigger( 'change' );
					return false;
				});
			}
		},
		contact: {
			selector: '.contact_map',
			init: function() {
				var base = this,
					container = $(base.selector);

				container.each(function() {
					var _this = $(this),
						mapzoom = _this.data('map-zoom'),
						mapstyle = _this.data('map-style'),
						mapType = _this.data('map-type'),
						panControl = _this.data('pan-control'),
						zoomControl = _this.data('zoom-control'),
						mapTypeControl = _this.data('maptype-control'),
						scaleControl = _this.data('scale-control'),
						streetViewControl = _this.data('streetview-control'),
						locations = _this.find('.thb-location'),
						once;

					var bounds = new google.maps.LatLngBounds();

					var mapOptions = {
						center: {
							lat: -34.397,
							lng: 150.644
						},
						styles: mapstyle,
						zoom: mapzoom,
						draggable: !("ontouchend" in document),
						scrollwheel: false,
						panControl: panControl,
						zoomControl: zoomControl,
						mapTypeControl: mapTypeControl,
						scaleControl: scaleControl,
						streetViewControl: streetViewControl,
						mapTypeId: mapType,
            gestureHandling: 'cooperative'
					};

					var map = new google.maps.Map(_this[0], mapOptions);

					map.addListener('tilesloaded', function() {
						if (!once) {
							locations.each(function(i) {
								var location = $(this),
										options = location.data('option'),
										lat = options.latitude,
										long = options.longitude,
										latlng = new google.maps.LatLng(lat, long),
										marker = options.marker_image,
										marker_size = options.marker_size,
										retina = options.retina_marker,
										title = options.marker_title,
										desc = options.marker_description,
										pinimageLoad = new Image();

								bounds.extend(latlng);

								pinimageLoad.src = marker;

								$(pinimageLoad).on('load', function(){
									base.setMarkers(i, locations.length, map, lat, long, marker, marker_size, title, desc, retina);
								});
									once = true;
							});

							if(mapzoom > 0) {
								map.setCenter(bounds.getCenter());
								map.setZoom(mapzoom);
							} else {
								map.setCenter(bounds.getCenter());
								map.fitBounds(bounds);
							}
						}
					});

					win.on('resize', _.debounce(function(){
						map.setCenter(bounds.getCenter());
					}, 50) );
				});
			},
			setMarkers: function(i, count, map, lat, long, marker, marker_size, title, desc, retina) {

				function showPin (i) {

					var markerExt = marker.toLowerCase().split('.');
							markerExt = markerExt[markerExt.length - 1];

					if($.inArray(markerExt, ['svg']) || retina ) {
						 marker = new google.maps.MarkerImage(marker, null, null, null, new google.maps.Size(marker_size[0]/2, marker_size[1]/2));
					}
					var g_marker = new google.maps.Marker({
								position: new google.maps.LatLng(lat,long),
								map: map,
								animation: google.maps.Animation.DROP,
								icon: marker,
								optimized: false
							}),
							contentString = '<h3>'+title+'</h3>'+'<div>'+desc+'</div>';

					// info windows
					var infowindow = new google.maps.InfoWindow({
							content: contentString
					});

					g_marker.addListener('click', function() {
				    infowindow.open(map, g_marker);
				  });
				}
				setTimeout(showPin, i * 250, i);
			}
		},
		themeSwitcher: {
			selector: '#theme-switcher',
			init: function() {
				var base = this,
						container = $(base.selector),
						toggle = container.find('.style-toggle');

				toggle.on('click', function() {
					container.add($(this)).toggleClass('active');
					return false;
				});

			}
		}
	};

	$(function(){
		if ($('#vc_inline-anchor').length) {
			win.on('vc_reload', function() {
				SITE.init();
			});
		} else {
			SITE.init();
		}
	});

})(jQuery, this, _);
