<?php
/**
 * Initialize the meta boxes.
 */
add_action( 'admin_init', 'thb_goodlife_custom_meta_boxes' );

/**
 * Meta Boxes demo code.
 *
 * You can find all the available option types
 * in demo-theme-options.php.
 *
 * @return    void
 *
 * @access    private
 * @since     2.0
 */


function thb_goodlife_custom_meta_boxes() {

	/**
	 * Create a custom meta boxes array that we pass to
	 * the OptionTree Meta Box API Class.
	 */

	$post_meta_box = array(
		'id'       => 'post_settings',
		'title'    => esc_html__( 'Post Settings', 'goodlife' ),
		'pages'    => apply_filters(
			'goodlife_post_metabox_pages',
			array( 'post' )
		),
		'context'  => 'normal',
		'priority' => 'high',
		'fields'   => array(
			array(
				'id'    => 'tab1',
				'label' => esc_html__( 'Settings', 'goodlife' ),
				'type'  => 'tab',
			),
			array(
				'label' => esc_html__( 'Primary Category', 'goodlife' ),
				'id'    => 'post-primary-category',
				'type'  => 'category_select_auto',
				'desc'  => esc_html__( 'If the posts has multiple categories, the one selected here will be used for settings and it appears in the category labels.', 'goodlife' ),
			),
			array(
				'label'    => esc_html__( 'Via Source', 'goodlife' ),
				'id'       => 'post_via',
				'type'     => 'list-item',
				'desc'     => esc_html__( 'You can add via sources for your articles here', 'goodlife' ),
				'settings' => array(
					array(
						'label' => esc_html__( 'Via Source URL', 'goodlife' ),
						'id'    => 'post_source_url',
						'desc'  => esc_html__( 'Enter a URL for your via source here', 'goodlife' ),
						'type'  => 'text',
					),
				),
			),
			array(
				'label'    => esc_html__( 'Source', 'goodlife' ),
				'id'       => 'post_source',
				'type'     => 'list-item',
				'desc'     => esc_html__( 'You can add sources for your articles here', 'goodlife' ),
				'settings' => array(
					array(
						'label' => esc_html__( 'Source URL', 'goodlife' ),
						'id'    => 'post_source_url',
						'desc'  => esc_html__( 'Enter a URL for your source here', 'goodlife' ),
						'type'  => 'text',
					),
				),
			),
			array(
				'id'    => 'tab2',
				'label' => esc_html__( 'Standard Post Layout', 'goodlife' ),
				'type'  => 'tab',
			),
			array(
				'id'    => 'post_layout_text',
				'label' => esc_html__( 'About Post Layout Settings', 'goodlife' ),
				'desc'  => esc_html__( 'These layouts are used for "Standard" post format.', 'goodlife' ),
				'type'  => 'textblock',
			),
			array(
				'label' => esc_html__( 'Override Default Article Style?', 'goodlife' ),
				'id'    => 'standard_article_style_override',
				'type'  => 'on_off',
				'desc'  => esc_html__( 'You can change the article style here', 'goodlife' ),
				'std'   => 'off',
			),
			array(
				'label'     => esc_html__( 'Standard Post Layout', 'goodlife' ),
				'id'        => 'standard-post-detail-style',
				'type'      => 'radio-image',
				'std'       => 'style1',
				'condition' => 'standard_article_style_override:is(on)',
			),
			array(
				'label'     => esc_html__( 'Featured Image', 'goodlife' ),
				'id'        => 'standard-featured-image',
				'type'      => 'on_off',
				'desc'      => esc_html__( 'You can choose to hide the featured image.', 'goodlife' ),
				'std'       => 'on',
				'condition' => 'standard-post-detail-style:is(style1)',
			),
			array(
				'label' => esc_html__( 'Featured Image Credit', 'goodlife' ),
				'id'    => 'standard-featured-credit',
				'type'  => 'text',
				'desc'  => esc_html__( 'Featured Image Credit, enter the copyright information for your featured image if needed.', 'goodlife' ),
			),
			array(
				'id'    => 'tab3',
				'label' => esc_html__( 'Gallery Post Layout', 'goodlife' ),
				'type'  => 'tab',
			),
			array(
				'id'    => 'gallery_post_layout_text',
				'label' => esc_html__( 'About Post Layout Settings', 'goodlife' ),
				'desc'  => esc_html__( 'These layouts are used for "Gallery" post format.', 'goodlife' ),
				'type'  => 'textblock',
			),
			array(
				'label' => esc_html__( 'Override Default Gallery Article Style?', 'goodlife' ),
				'id'    => 'gallery_article_style_override',
				'type'  => 'on_off',
				'desc'  => esc_html__( 'You can change the gallery article style here', 'goodlife' ),
				'std'   => 'off',
			),
			array(
				'label'     => esc_html__( 'Gallery Post Layout', 'goodlife' ),
				'id'        => 'gallery-post-detail-style',
				'type'      => 'radio-image',
				'std'       => 'style1',
				'condition' => 'gallery_article_style_override:is(on)',
			),
			array(
				'id'    => 'tab4',
				'label' => esc_html__( 'Video Post Layout', 'goodlife' ),
				'type'  => 'tab',
			),
			array(
				'id'    => 'video_post_layout_text',
				'label' => esc_html__( 'About Post Layout Settings', 'goodlife' ),
				'desc'  => esc_html__( 'These layouts are used for "Video" post format.', 'goodlife' ),
				'type'  => 'textblock',
			),
			array(
				'label' => esc_html__( 'Override Default Video Article Style?', 'goodlife' ),
				'id'    => 'video_article_style_override',
				'type'  => 'on_off',
				'desc'  => esc_html__( 'You can change the gallery article style here', 'goodlife' ),
				'std'   => 'off',
			),
			array(
				'label'     => esc_html__( 'Style', 'goodlife' ),
				'id'        => 'video_style',
				'type'      => 'radio-image',
				'desc'      => esc_html__( 'You can choose between 2 color sets for the video layout.', 'goodlife' ),
				'std'       => 'dark',
				'condition' => 'video_article_style_override:is(on)',
			),
			array(
				'label' => esc_html__( 'Video URL', 'goodlife' ),
				'id'    => 'post_video',
				'type'  => 'text',
				'desc'  => esc_html__( 'Video URL. You can find a list of websites you can embed here: <a href="http://codex.wordpress.org/Embeds">Wordpress Embeds</a>', 'goodlife' ),
				'std'   => '',
			),
			array(
				'label' => esc_html__( 'Display Other Videos bar?', 'goodlife' ),
				'id'    => 'other_videos',
				'type'  => 'on_off',
				'desc'  => esc_html__( 'You can enable the other videos bar here. It displays latest video posts.', 'goodlife' ),
				'std'   => 'on',
			),
			array(
				'label' => esc_html__( 'Video Post Layout', 'goodlife' ),
				'id'    => 'video-post-detail-style',
				'type'  => 'radio-image',
				'std'   => 'style2',
			),
			array(
				'id'    => 'tab5',
				'label' => esc_html__( 'Review Settings', 'goodlife' ),
				'type'  => 'tab',
			),
			array(
				'label' => esc_html__( 'Is this a review post?', 'goodlife' ),
				'id'    => 'is_review',
				'type'  => 'on_off',
				'desc'  => esc_html__( 'Select yes, if you would like to display review settings', 'goodlife' ),
				'std'   => 'off',
			),
			array(
				'label'     => esc_html__( 'Review Position', 'goodlife' ),
				'id'        => 'post-review-style',
				'type'      => 'radio',
				'choices'   => array(
					array(
						'label' => esc_html__( 'Top Full', 'goodlife' ),
						'value' => 'style1',
					),
					array(
						'label' => esc_html__( 'Top Half', 'goodlife' ),
						'value' => 'style2',
					),
					array(
						'label' => esc_html__( 'Bottom Full', 'goodlife' ),
						'value' => 'style3',
					),
				),
				'std'       => 'style3',
				'desc'      => esc_html__( 'Where would you like to display the reviews?', 'goodlife' ),
				'condition' => 'is_review:is(on)',
			),
			array(
				'label'     => esc_html__( 'Review Title', 'goodlife' ),
				'id'        => 'post_ratings_title',
				'type'      => 'text',
				'desc'      => esc_html__( 'Title of the review', 'goodlife' ),
				'condition' => 'is_review:is(on)',
			),
			array(
				'label'     => esc_html__( 'Ratings', 'goodlife' ),
				'id'        => 'post_ratings_percentage',
				'type'      => 'list-item',
				'desc'      => esc_html__( 'Please add ratings to rate this review for', 'goodlife' ),
				'settings'  => array(
					array(
						'label'        => esc_html__( 'Score', 'goodlife' ),
						'id'           => 'feature_score',
						'desc'         => esc_html__( 'Value should be between 0-10', 'goodlife' ),
						'std'          => '5',
						'type'         => 'numeric-slider',
						'min_max_step' => '0,10,1',
					),
				),
				'condition' => 'is_review:is(on)',
			),
			array(
				'label'     => esc_html__( 'Rating Average', 'goodlife' ),
				'id'        => 'post_ratings_average',
				'type'      => 'text',
				'desc'      => esc_html__( 'Average of the above ratings. You can override it if you want to.', 'goodlife' ),
				'condition' => 'is_review:is(on)',
			),
			array(
				'label'     => esc_html__( 'Comments Positive/Negative', 'goodlife' ),
				'id'        => 'post_ratings_comments',
				'type'      => 'list-item',
				'desc'      => esc_html__( 'Please add comments', 'goodlife' ),
				'settings'  => array(
					array(
						'label'   => esc_html__( 'Comment Type', 'goodlife' ),
						'id'      => 'feature_comment_type',
						'type'    => 'radio',
						'desc'    => esc_html__( 'Is this a negative or a positive comment?', 'goodlife' ),
						'choices' => array(
							array(
								'label' => esc_html__( 'Positive', 'goodlife' ),
								'value' => 'positive',
							),
							array(
								'label' => esc_html__( 'Negative', 'goodlife' ),
								'value' => 'negative',
							),
						),
						'std'     => 'negative',
					),
				),
				'condition' => 'is_review:is(on)',
			),
		),
	);

	/**
	 * Register our meta boxes using the
	 * ot_register_meta_box() function.
	 */

	ot_register_meta_box( $post_meta_box );
}
