<?php
/**
 * Initialize the options before anything else.
 */
add_action( 'admin_init', 'thb_goodlife_custom_theme_options', 1 );

/**
 * Theme Mode demo code of all the available option types.
 *
 * @return    void
 *
 * @access    private
 * @since     2.0
 */
function thb_goodlife_custom_theme_options() {

	/**
	 * Get a copy of the saved settings array.
	 */
	$saved_settings = get_option( 'option_tree_settings', array() );

	/**
	 * Create a custom settings array that we pass to
	 * the OptionTree Settings API Class.
	 */
	$custom_settings = array(
		'sections' => array(
			array(
				'title' => esc_html__( 'General', 'goodlife' ),
				'id'    => 'general',
			),
			array(
				'title' => esc_html__( 'Social Sharing', 'goodlife' ),
				'id'    => 'social',
			),
			array(
				'title' => esc_html__( 'Header Settings', 'goodlife' ),
				'id'    => 'header',
			),
			array(
				'title' => esc_html__( 'Category Settings', 'goodlife' ),
				'id'    => 'category_settings',
			),
			array(
				'title' => esc_html__( 'Customization', 'goodlife' ),
				'id'    => 'customization',
			),
			array(
				'title' => esc_html__( 'Typography', 'goodlife' ),
				'id'    => 'typography',
			),
			array(
				'title' => esc_html__( 'Advertisements', 'goodlife' ),
				'id'    => 'advertising',
			),
			array(
				'title' => esc_html__( 'Shop Settings', 'goodlife' ),
				'id'    => 'shop',
			),
			array(
				'title' => esc_html__( 'Footer Settings', 'goodlife' ),
				'id'    => 'footer',
			),
			array(
				'title' => esc_html__( 'Misc', 'goodlife' ),
				'id'    => 'misc',
			),
			array(
				'title' => esc_html__( 'GDPR', 'goodlife' ),
				'id'    => 'gdpr',
			),
		),
		'settings' => array(
			array(
				'id'      => 'general_tab1',
				'label'   => esc_html__( 'General', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'general',
			),
			array(
				'id'      => 'subscribe_text',
				'label'   => esc_html__( 'Download Subscription Emails', 'goodlife' ),
				'desc'    => __( 'You can download the subscribed emails through the subscription element/widget here: <br><br> <a href="?thb_download_emails=true" class="button button-primary">Download Emails</a>', 'goodlife' ),
				'type'    => 'textblock',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Dark Mode', 'goodlife' ),
				'id'      => 'thb_dark_mode',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'When you toggle this on, content will be adjusted to be displayed on a dark background. You can set your content background from Customization > Backgrounds. You can also set your body background from Appearance > Customize. Header & Footer has its own dark/light controls, so this wont affect them.', 'goodlife' ),
				'std'     => 'off',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Widget Title Style', 'goodlife' ),
				'id'      => 'widget_title_style',
				'type'    => 'radio-image',
				'std'     => 'title-style1',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Capitalized Article Titles', 'goodlife' ),
				'id'      => 'general_capitalize',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'When you toggle this on, all article titles will be capitalized.', 'goodlife' ),
				'std'     => 'off',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Display Single Category', 'goodlife' ),
				'id'      => 'general_single_category',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'When you toggle this off, all categories will be visible for a single post over the article title.', 'goodlife' ),
				'std'     => 'on',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Article Title Link Style', 'goodlife' ),
				'id'      => 'title_link_style',
				'type'    => 'radio',
				'choices' => array(
					array(
						'label' => esc_html__( 'Underline on Hover', 'goodlife' ),
						'value' => 'thb-title-underline-hover',
					),
					array(
						'label' => esc_html__( 'Change Color on Hover', 'goodlife' ),
						'value' => 'thb-title-color-hover',
					),
				),
				'desc'    => esc_html__( 'You can choose the link styles of article titles.', 'goodlife' ),
				'std'     => 'thb-title-underline-hover',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Boxed', 'goodlife' ),
				'id'      => 'general_boxed',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'This is mainly used to contain article headers especially if you have pageskin advertisements. Header & Footer have their own boxed settings.', 'goodlife' ),
				'std'     => 'off',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Lazy Load Images', 'goodlife' ),
				'id'      => 'lazy_load',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'If enabled, images will only be loaded when they come to view.', 'goodlife' ),
				'std'     => 'on',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Scroll to Top Arrow', 'goodlife' ),
				'id'      => 'scroll_totop',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'You can disable scroll to top arrow from here', 'goodlife' ),
				'std'     => 'on',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Use Relative Dates?', 'goodlife' ),
				'id'      => 'relative_dates',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'This will display dates as "1 day ago", etc.', 'goodlife' ),
				'std'     => 'on',
				'section' => 'general',
			),
			array(
				'id'      => 'general_tab3',
				'label'   => esc_html__( 'Articles', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Display Breadcrumbs?', 'goodlife' ),
				'id'      => 'article_breadcrumbs',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'You can show breadrumbs on your article pages.', 'goodlife' ),
				'std'     => 'on',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Display Reading Indicator?', 'goodlife' ),
				'id'      => 'reading_indicator',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'You can disable the reading progress indicator here. You can also change its color from customization tab.', 'goodlife' ),
				'std'     => 'on',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Infinite loading on Article Pages', 'goodlife' ),
				'id'      => 'infinite_load',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'You can disable infinite scrolling on article pages', 'goodlife' ),
				'std'     => 'on',
				'section' => 'general',
			),
			array(
				'label'     => esc_html__( 'Number of Infinite Loaded Articles', 'goodlife' ),
				'id'        => 'infinite_count',
				'type'      => 'text',
				'desc'      => esc_html__( 'Number of articles to load on scroll. Leave empty for no limit.', 'goodlife' ),
				'section'   => 'general',
				'condition' => 'infinite_load:is(on)',
			),
			array(
				'label'   => esc_html__( 'Latest/Related Posts', 'goodlife' ),
				'id'      => 'related_posts',
				'type'    => 'radio',
				'choices' => array(
					array(
						'label' => esc_html__( 'Latest Posts', 'goodlife' ),
						'value' => 'latest',
					),
					array(
						'label' => esc_html__( 'Related Posts', 'goodlife' ),
						'value' => 'related',
					),
					array(
						'label' => esc_html__( 'Off', 'goodlife' ),
						'value' => 'off',
					),
				),
				'desc'    => esc_html__( 'You can choose to display Latest Posts at the bottom of article pages.', 'goodlife' ),
				'std'     => 'latest',
				'section' => 'general',
			),
			array(
				'label'     => esc_html__( 'Number of Latest/Related Posts', 'goodlife' ),
				'id'        => 'related_count',
				'type'      => 'text',
				'desc'      => esc_html__( 'Number of latest/related posts to show, default is 6.', 'goodlife' ),
				'section'   => 'general',
				'condition' => 'related_posts:not(off)',
			),
			array(
				'label'   => esc_html__( 'Fixed Sidebars', 'goodlife' ),
				'id'      => 'article_fixed_sidebar',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'You can disable fixed sidebars on article pages', 'goodlife' ),
				'std'     => 'on',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Previous / Next Articles', 'goodlife' ),
				'id'      => 'article_prevnext',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'You can disable previous / next article links here', 'goodlife' ),
				'std'     => 'on',
				'section' => 'general',
			),
			array(
				'label'     => esc_html__( 'Limit Previous / Next Articles to same category?', 'goodlife' ),
				'id'        => 'article_prevnext_samecat',
				'type'      => 'on_off',
				'desc'      => esc_html__( 'Prev/Next articles will be limited to articles sharing the same categories', 'goodlife' ),
				'std'       => 'off',
				'section'   => 'general',
				'condition' => 'article_prevnext:is(on)',
			),
			array(
				'label'   => esc_html__( 'Author Information', 'goodlife' ),
				'id'      => 'article_author',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'You can disable author information on article pages', 'goodlife' ),
				'std'     => 'on',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Use LightBox for images?', 'goodlife' ),
				'id'      => 'article_lightbox',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'If you want to use your own lightbox, you can disable the theme lightbox here.', 'goodlife' ),
				'std'     => 'on',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Expanded Comments', 'goodlife' ),
				'id'      => 'article_expanded_comments',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'When enabled, comments will always be visible instead of being toggled.', 'goodlife' ),
				'std'     => 'off',
				'section' => 'general',
			),
			array(
				'id'      => 'general_tab4',
				'label'   => esc_html__( 'Article Style', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Default Article Style', 'goodlife' ),
				'id'      => 'standard-post-detail-style',
				'type'    => 'radio-image',
				'std'     => 'style1',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Default Article Style for Gallery Format', 'goodlife' ),
				'id'      => 'gallery-post-detail-style',
				'type'    => 'radio-image',
				'std'     => 'style1',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Default Article Style for Video Format', 'goodlife' ),
				'id'      => 'video-post-detail-style',
				'type'    => 'radio-image',
				'std'     => 'style1',
				'section' => 'general',
			),
			array(
				'id'      => 'general_tab5',
				'label'   => esc_html__( 'Article Meta', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Author Avatars', 'goodlife' ),
				'id'      => 'author_avatars',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'This will show small circular avatars next to author names', 'goodlife' ),
				'std'     => 'off',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Select Post Meta to HIDE', 'goodlife' ),
				'id'      => 'post_meta',
				'type'    => 'checkbox',
				'desc'    => esc_html__( 'You can choose to <strong>hide</strong> certain post meta here. This will remove the selected post meta globally. These are the small text under post post titles.', 'goodlife' ),
				'choices' => array(
					array(
						'label' => esc_html__( 'Author', 'goodlife' ),
						'value' => 'author',
					),
					array(
						'label' => esc_html__( 'Post Date', 'goodlife' ),
						'value' => 'post-date',
					),
					array(
						'label' => esc_html__( 'Comments', 'goodlife' ),
						'value' => 'comments',
					),
					array(
						'label' => esc_html__( 'Views', 'goodlife' ),
						'value' => 'views',
					),
				),
				'section' => 'general',
			),
			array(
				'id'      => 'general_tab6',
				'label'   => esc_html__( 'Mobile Menu', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Mobile Menu Style', 'goodlife' ),
				'id'      => 'mobile_menu_style',
				'type'    => 'radio',
				'desc'    => esc_html__( 'You can choose different mobile menu styles here', 'goodlife' ),
				'choices' => array(
					array(
						'label' => esc_html__( 'Style 1', 'goodlife' ),
						'value' => 'style1',
					),
					array(
						'label' => esc_html__( 'Style 2', 'goodlife' ),
						'value' => 'style2',
					),
				),
				'std'     => 'style1',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Menu Footer', 'goodlife' ),
				'id'      => 'menu_footer',
				'type'    => 'textarea',
				'desc'    => esc_html__( 'This content appears at the bottom of the mobile menu. You can use your shortcodes here.', 'goodlife' ),
				'rows'    => '4',
				'section' => 'general',
			),
			array(
				'id'      => 'social_tab1',
				'label'   => esc_html__( 'Social Sharing', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'social',
			),
			array(
				'label'   => esc_html__( 'Sharing buttons', 'goodlife' ),
				'id'      => 'sharing_buttons',
				'type'    => 'checkbox',
				'desc'    => esc_html__( 'You can choose which social networks to display and get counts from. Please visit <strong>Theme Options > Misc</strong> to fill out application details for the social media sites you choose.', 'goodlife' ),
				'choices' => array(
					array(
						'label' => esc_html__( 'Facebook', 'goodlife' ),
						'value' => 'facebook',
					),
					array(
						'label' => esc_html__( 'Twitter', 'goodlife' ),
						'value' => 'twitter',
					),
					array(
						'label' => esc_html__( 'Pinterest', 'goodlife' ),
						'value' => 'pinterest',
					),
					array(
						'label' => esc_html__( 'Linkedin', 'goodlife' ),
						'value' => 'linkedin',
					),
					array(
						'label' => esc_html__( 'WhatsApp', 'goodlife' ),
						'value' => 'whatsapp',
					),
				),
				'section' => 'social',
			),
			array(
				'label'   => esc_html__( 'Disable OG: Tags', 'goodlife' ),
				'id'      => 'general_disable_og_tags',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'If you want, you can disable the theme added Facebook OG tags if you are using a plugin like Yoast SEO or similar.', 'goodlife' ),
				'std'     => 'off',
				'section' => 'social',
			),
			array(
				'id'      => 'social_tab2',
				'label'   => esc_html__( 'Social Accounts', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'social',
			),
			array(
				'label'   => esc_html__( 'Facebook Username', 'goodlife' ),
				'id'      => 'facebook_page_username',
				'type'    => 'text',
				'desc'    => esc_html__( 'Your Facebook page username', 'goodlife' ),
				'section' => 'social',
			),
			array(
				'label'   => esc_html__( 'Twitter Username', 'goodlife' ),
				'id'      => 'twitter_bar_username',
				'type'    => 'text',
				'desc'    => esc_html__( 'Your Twitter Username', 'goodlife' ),
				'section' => 'social',
			),
			array(
				'label'   => esc_html__( 'Instagram Username', 'goodlife' ),
				'id'      => 'instagram_username',
				'type'    => 'text',
				'desc'    => esc_html__( 'Your Instagram Username', 'goodlife' ),
				'section' => 'social',
			),
			array(
				'label'   => esc_html__( 'Youtube Type', 'goodlife' ),
				'id'      => 'yt_type',
				'type'    => 'radio',
				'desc'    => esc_html__( 'Is this a channel or a user?', 'goodlife' ),
				'choices' => array(
					array(
						'label' => esc_html__( 'Channel', 'goodlife' ),
						'value' => 'channel',
					),
					array(
						'label' => esc_html__( 'Username', 'goodlife' ),
						'value' => 'username',
					),
				),
				'std'     => 'channel',
				'section' => 'social',
			),
			array(
				'label'   => esc_html__( 'Youtube Username or Channel ID', 'goodlife' ),
				'id'      => 'yt_id',
				'type'    => 'text',
				'desc'    => esc_html__( 'Your Youtube Username ID or Channel ID', 'goodlife' ),
				'section' => 'social',
			),
			array(
				'label'   => esc_html__( 'Google API Key for Youtube', 'goodlife' ),
				'id'      => 'social_youtube_api_key',
				'type'    => 'text',
				'desc'    => __( 'Please enter the Google Api Key for Youtube. You need to create a Credential that has access to YouTube Data API v3. Please visit <a href="https://cloud.google.com/" target="_blank">https://cloud.google.com/</a>', 'goodlife' ),
				'section' => 'social',
			),
			array(
				'label'   => esc_html__( 'Medium Username', 'goodlife' ),
				'id'      => 'social_medium_user',
				'type'    => 'text',
				'section' => 'general',
			),
			array(
				'label'   => esc_html__( 'Vimeo Channel Name', 'goodlife' ),
				'id'      => 'vimeo_channel',
				'type'    => 'text',
				'desc'    => esc_html__( 'Please enter your Vimeo channel name (example: "staffpicks")', 'goodlife' ),
				'section' => 'social',
			),
			array(
				'id'      => 'header_tab1',
				'label'   => esc_html__( 'Header Settings', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Header Style', 'goodlife' ),
				'id'      => 'header_style',
				'type'    => 'radio-image',
				'std'     => 'style1',
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Header Color', 'goodlife' ),
				'id'      => 'header_color',
				'type'    => 'radio-image',
				'desc'    => esc_html__( 'You can choose your header color here. This changes the icon and links colors inside the header. You can also change your header background from "Customization"', 'goodlife' ),
				'std'     => 'light',
				'section' => 'header',
			),
			array(
				'label'     => esc_html__( 'Menu Full Width', 'goodlife' ),
				'id'        => 'header_menu_width',
				'type'      => 'on_off',
				'desc'      => esc_html__( 'Would you like to use the menu full width?', 'goodlife' ),
				'std'       => 'off',
				'section'   => 'header',
				'operator'  => 'or',
				'condition' => 'header_style:is(style2), header_style:is(style8)',
			),
			array(
				'label'   => esc_html__( 'Menu Color', 'goodlife' ),
				'id'      => 'menu_color',
				'type'    => 'radio-image',
				'desc'    => esc_html__( 'You can choose your menu color here. This changes the background and links colors of the menu. You can also change your menu background from "Customization"', 'goodlife' ),
				'std'     => 'light',
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Mega Menu Style', 'goodlife' ),
				'id'      => 'mega_menu_style',
				'type'    => 'radio',
				'desc'    => esc_html__( 'You can change the mega menu style here.', 'goodlife' ),
				'choices' => array(
					array(
						'label' => esc_html__( 'Style1', 'goodlife' ),
						'value' => 'style1',
					),
					array(
						'label' => esc_html__( 'Style2', 'goodlife' ),
						'value' => 'style2',
					),
				),
				'std'     => 'style1',
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Boxed', 'goodlife' ),
				'id'      => 'header_boxed',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'Would you like to use the boxed style?', 'goodlife' ),
				'std'     => 'off',
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Fixed Header', 'goodlife' ),
				'id'      => 'header_fixed',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'You can enable/disable the fixed header functionality here.', 'goodlife' ),
				'std'     => 'on',
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Display Categories in Mega Menu posts', 'goodlife' ),
				'id'      => 'megamenu_categories',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'You can enable to display categories for posts inside the mega menu.', 'goodlife' ),
				'std'     => 'off',
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Search Icon', 'goodlife' ),
				'id'      => 'header_search',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'Would you like to display the search icon/form?', 'goodlife' ),
				'section' => 'header',
				'std'     => 'off',
			),
			array(
				'id'      => 'header_tab2',
				'label'   => esc_html__( 'Sub-Header Settings', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Display Sub-Header', 'goodlife' ),
				'id'      => 'subheader',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'Would you like to display the Sub-Header?', 'goodlife' ),
				'std'     => 'on',
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Boxed', 'goodlife' ),
				'id'      => 'subheader_boxed',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'Would you like to use the boxed style?', 'goodlife' ),
				'std'     => 'off',
				'section' => 'header',
			),
			array(
				'label'     => esc_html__( 'Sub-Header Full Width', 'goodlife' ),
				'id'        => 'subheader_grid',
				'type'      => 'on_off',
				'desc'      => esc_html__( 'You can enable/disable the full-width behaviour of the subheader here.', 'goodlife' ),
				'std'       => 'on',
				'section'   => 'header',
				'condition' => 'subheader_boxed:is(off)',
			),
			array(
				'label'   => esc_html__( 'Sub-Header Color', 'goodlife' ),
				'id'      => 'subheader_color',
				'type'    => 'radio',
				'desc'    => esc_html__( 'You can choose different header styles here', 'goodlife' ),
				'choices' => array(
					array(
						'label' => esc_html__( 'Style 1', 'goodlife' ),
						'value' => 'style1',
					),
					array(
						'label' => esc_html__( 'Style 2', 'goodlife' ),
						'value' => 'style2',
					),
					array(
						'label' => esc_html__( 'Style 3', 'goodlife' ),
						'value' => 'style3',
					),
				),
				'std'     => 'style1',
				'section' => 'header',
			),
			array(
				'label'     => esc_html__( 'Sub-Header Color', 'goodlife' ),
				'id'        => 'subheader_color',
				'type'      => 'radio-image',
				'desc'      => esc_html__( 'You can choose your subheader color here. You can also change your subheader background from "Customization"', 'goodlife' ),
				'std'       => 'light',
				'section'   => 'header',
				'condition' => 'subheader:is(on)',
			),
			array(
				'label'     => esc_html__( 'Language Switcher', 'goodlife' ),
				'id'        => 'subheader_ls',
				'type'      => 'on_off',
				'desc'      => esc_html__( 'Would you like to display the language switcher in the sub-header? <small>Requires that you have WPML installed. <a href="https://wpml.org/?aid=85928&affiliate_key=PIP3XupfKQOZ">You can purchase WPML here.</a></small>', 'goodlife' ),
				'section'   => 'header',
				'std'       => 'off',
				'condition' => 'subheader:is(on)',
			),
			array(
				'label'     => esc_html__( 'Search Icon', 'goodlife' ),
				'id'        => 'subheader_search',
				'type'      => 'on_off',
				'desc'      => esc_html__( 'Would you like to display the search icon/form?', 'goodlife' ),
				'section'   => 'header',
				'std'       => 'off',
				'condition' => 'subheader:is(on)',
			),
			array(
				'label'     => esc_html__( 'Login / Register Link', 'goodlife' ),
				'id'        => 'subheader_login_link',
				'type'      => 'on_off',
				'desc'      => esc_html__( 'Would you like to display the login/register link?', 'goodlife' ),
				'section'   => 'header',
				'std'       => 'off',
				'condition' => 'subheader:is(on)',
			),
			array(
				'label'     => esc_html__( 'Login / Register Popup Color', 'goodlife' ),
				'id'        => 'subheader_login_color',
				'type'      => 'radio-image',
				'desc'      => esc_html__( 'You can change the color of the login lightbox', 'goodlife' ),
				'std'       => 'light',
				'section'   => 'header',
				'condition' => 'subheader_login_link:is(on),subheader:is(on)',
			),
			array(
				'id'      => 'header_tab4',
				'label'   => esc_html__( 'Social Links in Sub-Header', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Display Dropdown or Icons?', 'goodlife' ),
				'id'      => 'social_links_style',
				'type'    => 'radio',
				'desc'    => esc_html__( 'You can choose either dropdown or icons', 'goodlife' ),
				'choices' => array(
					array(
						'label' => esc_html__( 'Dropdown', 'goodlife' ),
						'value' => 'style1',
					),
					array(
						'label' => esc_html__( 'Icons', 'goodlife' ),
						'value' => 'style2',
					),
				),
				'std'     => 'style1',
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Sub-Header Social Links', 'goodlife' ),
				'id'      => 'subheader_social_link',
				'type'    => 'social-links',
				'desc'    => esc_html__( 'Add your desired Social Links in the sub-header here.', 'goodlife' ),
				'section' => 'header',
			),
			array(
				'id'      => 'header_tab3',
				'label'   => esc_html__( 'Logo Settings', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Logo Upload', 'goodlife' ),
				'id'      => 'thb_logo',
				'type'    => 'upload',
				'desc'    => esc_html__( 'You can upload your own logo here. Since this theme is retina-ready, <strong>please upload a double size image.</strong> The image should be maximum 100 pixels in height.', 'goodlife' ),
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Logo Height', 'goodlife' ),
				'id'      => 'logo_height',
				'type'    => 'measurement',
				'desc'    => esc_html__( 'You can modify the logo height from here. This is maximum height, so your logo may get smaller depending on spacing inside header', 'goodlife' ),
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Mobile Logo Height', 'goodlife' ),
				'id'      => 'mobile_logo_height',
				'type'    => 'measurement',
				'desc'    => esc_html__( 'You can modify the logo height for the mobile screens here.', 'goodlife' ),
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Fixed Header Logo Upload', 'goodlife' ),
				'id'      => 'fixedlogo',
				'type'    => 'upload',
				'desc'    => esc_html__( 'You can upload your own logo here. Since this theme is retina-ready, <strong>please upload a double size image.</strong> The image should be maximum 100 pixels in height.', 'goodlife' ),
				'section' => 'header',
			),
			array(
				'label'   => esc_html__( 'Fixed Header Logo Height', 'goodlife' ),
				'id'      => 'fixedlogo_height',
				'type'    => 'measurement',
				'desc'    => esc_html__( 'You can modify the logo height from here. This is maximum height, so your logo may get smaller depending on spacing inside header', 'goodlife' ),
				'section' => 'header',
			),
			array(
				'id'      => 'category_settings_tab1',
				'label'   => esc_html__( 'Category Pages', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'category_settings',
			),
			array(
				'label'   => esc_html__( 'Category Title Style', 'goodlife' ),
				'id'      => 'category_title_style',
				'type'    => 'radio',
				'desc'    => esc_html__( 'Which style would you like to use for category titles?', 'goodlife' ),
				'choices' => array(
					array(
						'label' => esc_html__( 'Style 1', 'goodlife' ),
						'value' => 'style1',
					),
					array(
						'label' => esc_html__( 'Style 2', 'goodlife' ),
						'value' => 'style2',
					),
				),
				'std'     => 'style1',
				'section' => 'category_settings',
			),
			array(
				'label'   => esc_html__( 'Category Siblings', 'goodlife' ),
				'id'      => 'category_siblings',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'Would you like to display the category siblings?', 'goodlife' ),
				'std'     => 'on',
				'section' => 'category_settings',
			),
			array(
				'label'   => esc_html__( 'Category Listing Style', 'goodlife' ),
				'id'      => 'category_list_style',
				'type'    => 'radio',
				'desc'    => esc_html__( 'Which style would you like to use for category post listings?', 'goodlife' ),
				'choices' => array(
					array(
						'label' => esc_html__( 'Style 1 - Default', 'goodlife' ),
						'value' => 'style2',
					),
					array(
						'label' => esc_html__( 'Style 2 - Grid', 'goodlife' ),
						'value' => 'style3',
					),
				),
				'std'     => 'style2',
				'section' => 'category_settings',
			),
			array(
				'id'      => 'category_settings_tab2',
				'label'   => esc_html__( 'Category Colors', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'category_settings',
			),
			array(
				'label'   => esc_html__( 'Category Colors', 'goodlife' ),
				'id'      => 'category_colors',
				'type'    => 'category_colorpicker',
				'section' => 'category_settings',
			),
			array(
				'id'      => 'category_settings_tab3',
				'label'   => esc_html__( 'Category Sidebars', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'category_settings',
			),
			array(
				'label'   => esc_html__( 'Category Sidebars', 'goodlife' ),
				'id'      => 'category_sidebars',
				'type'    => 'category_sidebar_select',
				'section' => 'category_settings',
			),
			array(
				'id'      => 'category_settings_tab4',
				'label'   => esc_html__( 'Category Headers', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'category_settings',
			),
			array(
				'label'   => esc_html__( 'Category Grids', 'goodlife' ),
				'id'      => 'category_grids',
				'type'    => 'category_grid_select',
				'desc'    => esc_html__( 'Category Grid selection', 'goodlife' ),
				'choices' => array(
					'grid'    => array(
						array(
							'label' => esc_html__( 'No Grid', 'goodlife' ),
							'value' => '',
						),
						array(
							'label' => esc_html__( 'Style 1', 'goodlife' ),
							'value' => 'style1',
						),
						array(
							'label' => esc_html__( 'Style 2', 'goodlife' ),
							'value' => 'style2',
						),
						array(
							'label' => esc_html__( 'Style 3', 'goodlife' ),
							'value' => 'style3',
						),
						array(
							'label' => esc_html__( 'Style 4', 'goodlife' ),
							'value' => 'style4',
						),
					),
					'title'   => array(
						array(
							'label' => esc_html__( 'Title Position', 'goodlife' ),
							'value' => '',
						),
						array(
							'label' => esc_html__( 'Top Left', 'goodlife' ),
							'value' => 'top-title',
						),
						array(
							'label' => esc_html__( 'Center Center', 'goodlife' ),
							'value' => 'center-title',
						),
						array(
							'label' => esc_html__( 'Bottom Left', 'goodlife' ),
							'value' => 'bottom-title',
						),
					),
					'overlay' => array(
						array(
							'label' => esc_html__( 'Overlay Style', 'goodlife' ),
							'value' => '',
						),
						array(
							'label' => esc_html__( 'Standard', 'goodlife' ),
							'value' => 'standard',
						),
						array(
							'label' => esc_html__( 'Technology', 'goodlife' ),
							'value' => 'technology',
						),
					),
				),
				'std'     => '',
				'section' => 'category_settings',
			),
			array(
				'id'      => 'misc_tab1',
				'label'   => esc_html__( 'General', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'misc',
			),
			array(
				'label'   => esc_html__( 'Use Combined JavaScript Library?', 'goodlife' ),
				'id'      => 'thb_combined_libraries',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'When disabled, each javascript library will be loaded on its own. It will allow for greater control using plugins, but may hinder site speed as multiple files will be loaded instead of one.', 'goodlife' ),
				'std'     => 'on',
				'section' => 'misc',
			),
			array(
				'label'   => esc_html__( 'Google Maps API Key', 'goodlife' ),
				'id'      => 'map_api_key',
				'type'    => 'text',
				'desc'    => __( 'Please enter the Google Maps Api Key. <small>You need to create a browser API key. For more information, please visit: <a href="https://developers.google.com/maps/documentation/javascript/get-api-key" target="_blank">https://developers.google.com/maps/documentation/javascript/get-api-key</a></small>', 'goodlife' ),
				'section' => 'misc',
			),
			array(
				'label'   => esc_html__( 'Coinmarketcap.com API Key', 'goodlife' ),
				'id'      => 'cmc_api_key',
				'type'    => 'text',
				'desc'    => __( 'Please enter the CMC Api Key. <small>You can get your API Key from: <a href="https://pro.coinmarketcap.com/" target="_blank">https://pro.coinmarketcap.com/</a></small>', 'goodlife' ),
				'section' => 'misc',
			),
			array(
				'label'   => esc_html__( 'Extra CSS', 'goodlife' ),
				'id'      => 'extra_css',
				'type'    => 'css',
				'desc'    => esc_html__( 'Any CSS that you would like to add to the theme.', 'goodlife' ),
				'section' => 'misc',
			),
			array(
				'id'      => 'misc_tab12',
				'label'   => esc_html__( '404 Page', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'misc',
			),
			array(
				'label'   => esc_html__( '404 Page Image', 'goodlife' ),
				'id'      => '404-image',
				'type'    => 'upload',
				'desc'    => esc_html__( 'This will change the actual 404 image in the middle.', 'goodlife' ),
				'section' => 'misc',
			),
			array(
				'id'      => 'misc_tab8',
				'label'   => esc_html__( 'Create Additional Sidebars', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'misc',
			),
			array(
				'id'      => 'sidebars_text',
				'label'   => esc_html__( 'About the sidebars', 'goodlife' ),
				'desc'    => esc_html__( 'All sidebars that you create here will appear both in the Widgets Page(Appearance > Widgets), from where you will have to configure them, and in the pages, where you will be able to choose a sidebar for each page', 'goodlife' ),
				'std'     => '',
				'type'    => 'textblock',
				'section' => 'misc',
			),
			array(
				'label'    => esc_html__( 'Create Sidebars', 'goodlife' ),
				'id'       => 'sidebars',
				'type'     => 'list-item',
				'desc'     => esc_html__( 'Please choose a unique title for each sidebar!', 'goodlife' ),
				'section'  => 'misc',
				'settings' => array(
					array(
						'label' => esc_html__( 'ID', 'goodlife' ),
						'id'    => 'id',
						'type'  => 'text',
						'desc'  => esc_html__( 'Please write a lowercase id, with <strong>no spaces</strong>', 'goodlife' ),
					),
				),
			),
			array(
				'id'      => 'customization_tab0',
				'label'   => esc_html__( 'Colors', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Accent Color', 'goodlife' ),
				'id'      => 'accent_color',
				'type'    => 'colorpicker',
				'desc'    => esc_html__( 'Change the accent color used throughout the theme', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Header Search Color', 'goodlife' ),
				'id'      => 'header_search_color',
				'type'    => 'colorpicker',
				'desc'    => esc_html__( 'Change the search color inside the header and subheader', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Reading Indicator Color', 'goodlife' ),
				'id'      => 'reading_indicator_color',
				'type'    => 'colorpicker',
				'desc'    => esc_html__( 'Change the reading_indicator color used on article pages', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Sidebar Widget Title Color', 'goodlife' ),
				'id'      => 'sidebar_widget_title_color',
				'type'    => 'colorpicker',
				'desc'    => esc_html__( 'Change the title colors of the widgets on the sidebars', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Footer Widget Title Color', 'goodlife' ),
				'id'      => 'footer_widget_title_color',
				'type'    => 'colorpicker',
				'desc'    => esc_html__( 'Change the title colors of the widgets inside the footer', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'id'      => 'customization_tab3',
				'label'   => esc_html__( 'Backgrounds', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Content Background', 'goodlife' ),
				'id'      => 'content_bg',
				'type'    => 'colorpicker',
				'desc'    => esc_html__( 'Background setting for the main content. You can also use Appearance > Customize > Colors > Background Color to change the body background.', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Sub-Header Background', 'goodlife' ),
				'id'      => 'subheader_bg',
				'type'    => 'background',
				'desc'    => esc_html__( 'Background settings for the sub-header', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Header Background', 'goodlife' ),
				'id'      => 'header_bg',
				'type'    => 'background',
				'desc'    => esc_html__( 'Background settings for the header', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Menu Background', 'goodlife' ),
				'id'      => 'menu_bg',
				'type'    => 'background',
				'desc'    => esc_html__( 'Background settings for the menu. Works with Style1 header', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Mobile - Menu Background', 'goodlife' ),
				'id'      => 'mobile_menu_bg',
				'type'    => 'background',
				'desc'    => esc_html__( 'Background settings for the mobile menu.', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Footer Background', 'goodlife' ),
				'id'      => 'footer_bg',
				'type'    => 'background',
				'desc'    => esc_html__( 'Background settings for the footer.', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Sub-Footer Background', 'goodlife' ),
				'id'      => 'subfooter_bg',
				'type'    => 'background',
				'desc'    => esc_html__( 'Background settings for the sub-footer.', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Widget Background', 'goodlife' ),
				'id'      => 'widget_bg',
				'type'    => 'background',
				'desc'    => esc_html__( 'Background settings for the sidebar widgets.', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Login/Register Lightbox Background', 'goodlife' ),
				'id'      => 'login_bg',
				'type'    => 'background',
				'desc'    => esc_html__( 'Background settings for the Login/Register Lightbox.', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'id'      => 'customization_tab4',
				'label'   => esc_html__( 'Measurements', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'customization',
			),
			array(
				'id'      => 'header_menu_margin',
				'label'   => esc_html__( 'Top Level Menu Item spacing', 'goodlife' ),
				'desc'    => esc_html__( 'If you want to fit more menu items to the given space, you can decrease the margin between them here. The default margin is 20px', 'goodlife' ),
				'type'    => 'measurement',
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Logo Padding', 'goodlife' ),
				'id'      => 'logo_padding',
				'type'    => 'spacing',
				'desc'    => esc_html__( 'You can modify the logo padding here', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Widget Padding', 'goodlife' ),
				'id'      => 'widget_padding',
				'type'    => 'spacing',
				'desc'    => esc_html__( 'You can modify the sidebar widget padding here', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Footer Padding', 'goodlife' ),
				'id'      => 'footer_padding',
				'type'    => 'spacing',
				'desc'    => esc_html__( 'You can modify the footer padding here', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Sub-Footer Padding', 'goodlife' ),
				'id'      => 'subfooter_padding',
				'type'    => 'spacing',
				'desc'    => esc_html__( 'You can modify the subfooter padding here', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'id'      => 'customization_tab5',
				'label'   => esc_html__( 'Other', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'customization',
			),
			array(
				'label'   => esc_html__( 'Custom 404 Page', 'goodlife' ),
				'id'      => '404_page_content',
				'type'    => 'page-select',
				'desc'    => esc_html__( 'This allows you to override default 404 page and show a custom page.', 'goodlife' ),
				'section' => 'customization',
			),
			array(
				'id'      => 'typography_tab1',
				'label'   => esc_html__( 'Font Families', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'typography',
			),
			array(
				'id'      => 'font_cache_text',
				'label'   => esc_html__( 'Clear Font Cache', 'goodlife' ),
				'desc'    => __( 'If you cant find Google Webfonts inside the boxes below, you can clear your transient for the font cache here: <br><br> <a href="themes.php?page=ot-theme-options&thb_clear_font_cache=true" class="button button-primary">Clear Font Cache</a>', 'goodlife' ),
				'type'    => 'textblock',
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Primary Font', 'goodlife' ),
				'id'      => 'title_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Family for the heading tags and titles', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Secondary Font', 'goodlife' ),
				'id'      => 'body_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Family for general font', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Main Menu Font', 'goodlife' ),
				'id'      => 'menu_left_font',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Family for the main menu', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Main Menu Submenu Font', 'goodlife' ),
				'id'      => 'menu_left_submenu_font',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Family for the submenu elements of the main menu', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Mobile Menu Font', 'goodlife' ),
				'id'      => 'menu_mobile_font',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Family for the mobile menu', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Mobile Menu Submenu Font', 'goodlife' ),
				'id'      => 'menu_mobile_submenu_font',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Family for the submenu elements of the mobile menu', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Post Category Title Font', 'goodlife' ),
				'id'      => 'category_title_font',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Family for the category titles above post titles.', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Post Meta Font', 'goodlife' ),
				'id'      => 'post_meta_font',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Family for the post meta below post titles.', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Widget Title Font', 'goodlife' ),
				'id'      => 'widget_title_font',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Family for Widget Titles', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Button Font', 'goodlife' ),
				'id'      => 'button_font',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Family for the buttons.', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'id'      => 'typography_tab2',
				'label'   => esc_html__( 'Typography', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Post Title Typography', 'goodlife' ),
				'id'      => 'post_title_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the main menu', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Main Menu Typography', 'goodlife' ),
				'id'      => 'menu_left_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the main menu', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Main Menu Submenu Typography', 'goodlife' ),
				'id'      => 'menu_left_submenu_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the submenu elements of the main menu', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Mobile Menu Typography', 'goodlife' ),
				'id'      => 'menu_mobile_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the mobile menu', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Mobile Menu Submenu Typography', 'goodlife' ),
				'id'      => 'menu_mobile_submenu_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the submenu elements of the mobile menu', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Sub Header Typography', 'goodlife' ),
				'id'      => 'subheader_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the subheader', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Post Category Title Typography', 'goodlife' ),
				'id'      => 'category_title_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the category titles above post titles.', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Post Meta Typography', 'goodlife' ),
				'id'      => 'post_meta_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the post meta below post titles.', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Widget Title Typography', 'goodlife' ),
				'id'      => 'widget_title_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for Widget Titles', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'id'      => 'typography_tab3',
				'label'   => esc_html__( 'Heading Typography', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'typography',
			),
			array(
				'id'      => 'heading_text',
				'label'   => esc_html__( 'About Heading Typography', 'goodlife' ),
				'desc'    => esc_html__( 'These affect all h* tags inside the theme, so use wisely. Some particular headings may need additional css to target.', 'goodlife' ),
				'type'    => 'textblock',
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Heading 1', 'goodlife' ),
				'id'      => 'h1_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the H1 tag', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Heading 2', 'goodlife' ),
				'id'      => 'h2_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the H2 tag', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Heading 3', 'goodlife' ),
				'id'      => 'h3_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the H3 tag', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Heading 4', 'goodlife' ),
				'id'      => 'h4_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the H4 tag', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Heading 5', 'goodlife' ),
				'id'      => 'h5_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the H5 tag', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Heading 6', 'goodlife' ),
				'id'      => 'h6_type',
				'type'    => 'typography',
				'desc'    => esc_html__( 'Font Settings for the H6 tag', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'id'      => 'typography_tab4',
				'label'   => esc_html__( 'Font Support', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Google WebFont Subsets', 'goodlife' ),
				'id'      => 'font_subsets',
				'type'    => 'radio',
				'desc'    => esc_html__( 'You can add additional character subset specific to your language.', 'goodlife' ),
				'choices' => array(
					array(
						'label' => esc_html__( 'No Subset', 'goodlife' ),
						'value' => 'no-subset',
					),
					array(
						'label' => esc_html__( 'Latin Extended', 'goodlife' ),
						'value' => 'latin-ext',
					),
					array(
						'label' => esc_html__( 'Greek', 'goodlife' ),
						'value' => 'greek',
					),
					array(
						'label' => esc_html__( 'Cyrillic', 'goodlife' ),
						'value' => 'cyrillic',
					),
					array(
						'label' => esc_html__( 'Vietnamese', 'goodlife' ),
						'value' => 'vietnamese',
					),
				),
				'std'     => 'no-subset',
				'section' => 'typography',
			),
			array(
				'id'      => 'typekit_text',
				'label'   => esc_html__( 'About Typekit Support', 'goodlife' ),
				'desc'    => esc_html__( 'Please make sure that you enter your Typekit ID or the fonts wont work. After adding Typekit Font Names, these names will appear on the font selection dropdown on the Typography tab.', 'goodlife' ),
				'type'    => 'textblock',
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Adobe Fonts Kit ID', 'goodlife' ),
				'id'      => 'typekit_id',
				'type'    => 'text',
				'desc'    => esc_html__( 'Paste the provided Adobe Fonts Kit ID. <small>Usually 6-7 random letters</small>', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'   => esc_html__( 'Adobe Font Names', 'goodlife' ),
				'id'      => 'typekit_fonts',
				'type'    => 'text',
				'desc'    => esc_html__( 'Enter your Adobe Font Name, seperated by comma. For example: futura-pt,aktiv-grotesk <strong>Do not leave spaces between commas</strong>', 'goodlife' ),
				'section' => 'typography',
			),
			array(
				'label'    => esc_html__( 'Self Hosted Fonts', 'goodlife' ),
				'id'       => 'self_hosted_fonts',
				'type'     => 'list-item',
				'settings' => array(
					array(
						'label'   => esc_html__( 'Font Stylesheet URL', 'goodlife' ),
						'id'      => 'font_url',
						'type'    => 'text',
						'desc'    => esc_html__( 'URL of the font stylesheet (.css file) you want to use.', 'goodlife' ),
						'section' => 'typography',
					),
					array(
						'label'   => esc_html__( 'Font Family Names', 'goodlife' ),
						'id'      => 'font_name',
						'type'    => 'text',
						'desc'    => esc_html__( 'Enter your Font Family Name, use the name that will be used in css. For example: futura-pt, aktiv-grotesk. After saving, you will be able to use this name in the typography settings.', 'goodlife' ),
						'section' => 'typography',
					),
				),
				'section'  => 'typography',
			),
			array(
				'id'      => 'advertising_tab1',
				'label'   => esc_html__( 'General', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'advertising',
			),
			array(
				'label'   => esc_html__( 'Page Skin Content', 'goodlife' ),
				'id'      => 'thb_ads_pageskin',
				'type'    => 'textarea',
				'desc'    => esc_html__( 'Content of the pageskin to be displayed below the header', 'goodlife' ),
				'rows'    => '4',
				'section' => 'advertising',
			),
			array(
				'label'   => esc_html__( 'Header Ad', 'goodlife' ),
				'id'      => 'thb_ads_header',
				'type'    => 'textarea',
				'desc'    => esc_html__( 'This content appears next to the logo. You can also use shortcodes here. Appears on the left for center logo layouts.', 'goodlife' ),
				'rows'    => '4',
				'section' => 'advertising',
			),
			array(
				'label'   => esc_html__( 'Display Header Ad on mobile?', 'goodlife' ),
				'id'      => 'thb_ads_header_mobile',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'If you want, you can display the header ad on mobile.', 'goodlife' ),
				'std'     => 'off',
				'section' => 'advertising',
			),
			array(
				'label'   => esc_html__( 'Header Ad - Right', 'goodlife' ),
				'id'      => 'thb_ads_header_2',
				'type'    => 'textarea',
				'desc'    => esc_html__( 'This content appears next to the logo. You can also use shortcodes here. Appears on the right for center logo layouts.', 'goodlife' ),
				'rows'    => '4',
				'section' => 'advertising',
			),
			array(
				'id'      => 'advertising_tab2',
				'label'   => esc_html__( 'Articles', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'advertising',
			),
			array(
				'label'   => esc_html__( 'Before Title', 'goodlife' ),
				'id'      => 'thb_ads_before_title',
				'type'    => 'textarea',
				'desc'    => esc_html__( 'This content appears before the title in article pages. Applies to Standard Post Formats.', 'goodlife' ),
				'rows'    => '4',
				'section' => 'advertising',
			),
			array(
				'label'   => esc_html__( 'Before Content', 'goodlife' ),
				'id'      => 'thb_ads_before_content',
				'type'    => 'textarea',
				'desc'    => esc_html__( 'This content appears before the content in article pages. Applies to Standard Post Formats.', 'goodlife' ),
				'rows'    => '4',
				'section' => 'advertising',
			),
			array(
				'label'   => esc_html__( 'After Content', 'goodlife' ),
				'id'      => 'thb_ads_after_content',
				'type'    => 'textarea',
				'desc'    => esc_html__( 'This content appears after the content in article pages. Applies to Standard Post Formats.', 'goodlife' ),
				'rows'    => '4',
				'section' => 'advertising',
			),
			array(
				'label'   => esc_html__( 'After Article', 'goodlife' ),
				'id'      => 'thb_ads_after_article',
				'type'    => 'textarea',
				'desc'    => esc_html__( 'This content appears at the end of the article. Applies to Standard Post Formats.', 'goodlife' ),
				'rows'    => '4',
				'section' => 'advertising',
			),
			array(
				'id'      => 'advertising_tab4',
				'label'   => esc_html__( 'Video Monetization', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'advertising',
			),
			array(
				'id'      => 'viai_text',
				'label'   => esc_html__( 'About Video Monetization', 'goodlife' ),
				'desc'    => __( '1) Sign up for a <a href="https://www.vi.ai/publisher-video-monetization/" target="_blank">vi.ai account.</a><br>2)Grab your publisher ID from the code snippet.', 'goodlife' ),
				'type'    => 'textblock',
				'section' => 'advertising',
			),
			array(
				'label'   => esc_html__( 'Custom Video Player', 'goodlife' ),
				'id'      => 'thb_custom_video_player',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'You can disable the custom video player here. However, you wont be able to use the monetization features', 'goodlife' ),
				'std'     => 'on',
				'section' => 'advertising',
			),
			array(
				'label'   => esc_html__( 'VI.AI Publisher ID', 'goodlife' ),
				'id'      => 'viai_publisher_id',
				'type'    => 'text',
				'desc'    => esc_html__( 'Enter your vi.ai Publisher ID here.', 'goodlife' ),
				'section' => 'advertising',
			),
			array(
				'label'   => esc_html__( 'Shop Sidebar', 'goodlife' ),
				'id'      => 'shop_sidebar',
				'type'    => 'radio',
				'desc'    => esc_html__( 'Would you like to display sidebar on shop main and category pages?', 'goodlife' ),
				'choices' => array(
					array(
						'label' => esc_html__( 'No Sidebar', 'goodlife' ),
						'value' => 'no',
					),
					array(
						'label' => esc_html__( 'Right Sidebar', 'goodlife' ),
						'value' => 'right',
					),
					array(
						'label' => esc_html__( 'Left Sidebar', 'goodlife' ),
						'value' => 'left',
					),
				),
				'std'     => 'no',
				'section' => 'shop',
			),
			array(
				'label'   => esc_html__( 'Products Per Page', 'goodlife' ),
				'id'      => 'products_per_page',
				'type'    => 'text',
				'section' => 'shop',
				'std'     => '12',
			),
			array(
				'label'        => esc_html__( 'Products Per Row', 'goodlife' ),
				'id'           => 'products_per_row',
				'std'          => '4',
				'type'         => 'numeric-slider',
				'section'      => 'shop',
				'min_max_step' => '2,6,1',
			),
			array(
				'id'      => 'footer_tab1',
				'label'   => esc_html__( 'Footer', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'footer',
			),
			array(
				'label'   => esc_html__( 'Display Footer', 'goodlife' ),
				'id'      => 'footer',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'Would you like to display the Footer?', 'goodlife' ),
				'std'     => 'on',
				'section' => 'footer',
			),
			array(
				'label'     => esc_html__( 'Boxed', 'goodlife' ),
				'id'        => 'footer_boxed',
				'type'      => 'on_off',
				'desc'      => esc_html__( 'Would you like to use the boxed style?', 'goodlife' ),
				'std'       => 'off',
				'section'   => 'footer',
				'condition' => 'footer:is(on)',
			),
			array(
				'label'     => esc_html__( 'Footer Columns', 'goodlife' ),
				'id'        => 'footer_columns',
				'type'      => 'radio-image',
				'std'       => 'threecolumns',
				'section'   => 'footer',
				'condition' => 'footer:is(on)',
			),
			array(
				'label'     => esc_html__( 'Footer Color', 'goodlife' ),
				'id'        => 'footer_color',
				'type'      => 'radio-image',
				'desc'      => esc_html__( 'You can choose your footer color here. You can also change your footer background from "Customization"', 'goodlife' ),
				'std'       => 'dark',
				'section'   => 'footer',
				'condition' => 'footer:is(on)',
			),
			array(
				'id'      => 'footer_tab2',
				'label'   => esc_html__( 'Sub Footer', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'footer',
			),
			array(
				'label'   => esc_html__( 'Display Sub Footer', 'goodlife' ),
				'id'      => 'subfooter',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'Would you like to display the Sub Footer?', 'goodlife' ),
				'std'     => 'on',
				'section' => 'footer',
			),
			array(
				'label'     => esc_html__( 'Sub-Footer Style', 'goodlife' ),
				'id'        => 'subfooter_style',
				'type'      => 'radio-image',
				'desc'      => esc_html__( 'You can change the layout of the sub-footer here', 'goodlife' ),
				'std'       => 'style1',
				'section'   => 'footer',
				'condition' => 'subfooter:is(on)',
			),
			array(
				'label'     => esc_html__( 'Boxed', 'goodlife' ),
				'id'        => 'subfooter_boxed',
				'type'      => 'on_off',
				'desc'      => esc_html__( 'Would you like to use the boxed style?', 'goodlife' ),
				'std'       => 'off',
				'section'   => 'footer',
				'condition' => 'subfooter:is(on)',
			),
			array(
				'label'     => esc_html__( 'Sub-Footer Color', 'goodlife' ),
				'id'        => 'subfooter_color',
				'type'      => 'radio-image',
				'desc'      => esc_html__( 'You can choose your sub-footer color here. You can also change your sub-footer background from "Customization"', 'goodlife' ),
				'std'       => 'dark',
				'section'   => 'footer',
				'condition' => 'subfooter:is(on)',
			),
			array(
				'label'     => esc_html__( 'Display Sub Footer Logo', 'goodlife' ),
				'id'        => 'subfooter_logo_switch',
				'type'      => 'on_off',
				'desc'      => esc_html__( 'Would you like to display the Sub Footer?', 'goodlife' ),
				'std'       => 'on',
				'section'   => 'footer',
				'condition' => 'subfooter:is(on)',
			),
			array(
				'label'     => esc_html__( 'Sub Footer Logo', 'goodlife' ),
				'id'        => 'subfooter_logo',
				'type'      => 'upload',
				'desc'      => esc_html__( 'You can upload your own subfooter logo here. Since this theme is retina-ready, <strong>please upload a double size image.</strong>', 'goodlife' ),
				'section'   => 'footer',
				'condition' => 'subfooter:is(on),subfooter_logo_switch:is(on)',
			),
			array(
				'label'     => esc_html__( 'Sub Footer Logo Height', 'goodlife' ),
				'id'        => 'subfooter_logo_height',
				'type'      => 'measurement',
				'desc'      => esc_html__( 'You can modify the subfooter logo height from here. This is maximum height, so your logo may get smaller depending on screen size', 'goodlife' ),
				'section'   => 'footer',
				'condition' => 'subfooter:is(on),subfooter_logo_switch:is(on)',
			),
			array(
				'label'     => esc_html__( 'Sub-Footer Social Links', 'goodlife' ),
				'id'        => 'subfooter_social_link',
				'type'      => 'social-links',
				'desc'      => esc_html__( 'Add your desired Social Links in the sub-footer here.', 'goodlife' ),
				'section'   => 'footer',
				'condition' => 'subfooter:is(on)',
			),
			array(
				'label'     => esc_html__( 'Copyright Text', 'goodlife' ),
				'id'        => 'copyright',
				'type'      => 'text',
				'desc'      => esc_html__( 'Copyright Text at the bottom left', 'goodlife' ),
				'section'   => 'footer',
				'condition' => 'subfooter:is(on)',
			),
			array(
				'id'      => 'gdpr_tab1',
				'label'   => esc_html__( 'Cookie Bar', 'goodlife' ),
				'type'    => 'tab',
				'section' => 'gdpr',
			),
			array(
				'label'   => esc_html__( 'Cookie Bar', 'goodlife' ),
				'id'      => 'thb_cookie_bar',
				'type'    => 'on_off',
				'desc'    => esc_html__( 'Would you like to show the cookie bar?', 'goodlife' ),
				'std'     => 'on',
				'section' => 'gdpr',
			),
			array(
				'label'     => esc_html__( 'Cookie Bar Content', 'goodlife' ),
				'id'        => 'thb_cookie_bar_content',
				'type'      => 'textarea',
				'desc'      => esc_html__( 'This content appears inside the cookie bar.', 'goodlife' ),
				'rows'      => '4',
				'section'   => 'gdpr',
				'condition' => 'thb_cookie_bar:is(on)',
			),
		),
	);

	/* settings are not the same update the DB */
	if ( $saved_settings !== $custom_settings ) {
		update_option( 'option_tree_settings', $custom_settings );
	}
}
/**
 * Category Select option type.
 *
 * See @ot_display_by_type to see the full list of available arguments.
 *
 * @param     array     An array of arguments.
 * @return    string
 *
 * @access    public
 * @since     2.0
 */
if ( ! function_exists( 'ot_type_category_select_auto' ) ) {

	function ot_type_category_select_auto( $args = array() ) {

		/* turns arguments array into variables */
		extract( $args );

		/* verify a description */
		$has_desc = $field_desc ? true : false;

		/* format setting outer wrapper */
		echo '<div class="format-setting type-category-select ' . ( $has_desc ? 'has-desc' : 'no-desc' ) . '">';

			/* description */
		if ( $has_desc ) {
			echo '<div class="description">' . wp_kses_post( wp_specialchars_decode( $field_desc ) ) . '</div>'; }

			/* format setting inner wrapper */
			echo '<div class="format-setting-inner">';

				/* build category */
				echo '<select name="' . esc_attr( $field_name ) . '" id="' . esc_attr( $field_id ) . '" class="option-tree-ui-select ' . $field_class . '">';

				/* get category array */
				$categories = get_categories( apply_filters( 'ot_type_category_select_query', array( 'hide_empty' => false ), $field_id ) );

				echo '<option value="auto">' . esc_html__( 'Auto Select a Category', 'goodlife' ) . '</option>';

				/* has cats */
		if ( ! empty( $categories ) ) {
			foreach ( $categories as $category ) {
				echo '<option value="' . esc_attr( $category->term_id ) . '"' . selected( $field_value, $category->term_id, false ) . '>' . esc_attr( $category->name ) . '</option>';
			}
		} else {
			echo '<option value="">' . esc_html__( 'No Categories Found', 'goodlife' ) . '</option>';
		}

				echo '</select>';

			echo '</div>';

		echo '</div>';

	}
}

/**
 * Category Colorpicker option type.
 *
 * See @ot_display_by_type to see the full list of available arguments.
 *
 * @param     array     An array of arguments.
 * @return    string
 *
 * @access    public
 * @since     2.0
 */
if ( ! function_exists( 'ot_type_category_colorpicker' ) ) {

	function ot_type_category_colorpicker( $args = array() ) {

		/* turns arguments array into variables */
		extract( $args );

		/* verify a description */
		$has_desc = $field_desc ? true : false;

		$args = array(
			'type'         => 'post',
			'child_of'     => 0,
			'parent'       => '',
			'orderby'      => 'name',
			'order'        => 'ASC',
			'hide_empty'   => 0,
			'hierarchical' => 0,
			'exclude'      => '',
			'include'      => '',
			'number'       => '',
			'taxonomy'     => 'category',
			'pad_counts'   => false,

		);
		global $sitepress;

		if ( $sitepress ) {
			remove_filter( 'terms_clauses', array( $sitepress, 'terms_clauses' ) );
		}
		$categories = get_terms( 'category', array( 'hide_empty' => false ) );

		foreach ( $categories as $category ) {
			$field_id    = 'category_colors_' . $category->term_id;
			$field_name  = 'option_tree[category_colors_' . $category->term_id . ']';
			$field_value = ot_get_option( $field_id );

			/* format setting outer wrapper */
			echo '<div class="format-setting type-colorpicker has-desc format-settings">';

				/* description */
				echo '<div class="description">Category color for "' . $category->name . '"</div>';

				/* format setting inner wrapper */
				echo '<div class="format-setting-inner">';

					/* build colorpicker */
					echo '<div class="option-tree-ui-colorpicker-input-wrap">';

						/* colorpicker JS */
						echo '<script>jQuery(document).ready(function($) { OT_UI.bind_colorpicker("' . esc_attr( $field_id ) . '"); });</script>';

						/* input */
						echo '<input type="text" name="' . esc_attr( $field_name ) . '" id="' . esc_attr( $field_id ) . '" value="' . esc_attr( $field_value ) . '" class="widefat option-tree-ui-input cp_input ' . esc_attr( $field_class ) . '" autocomplete="off" />';

						/* set border color */
						$border_color = in_array( $field_value, array( '#FFFFFF', '#FFF', '#ffffff', '#fff' ) ) ? '#ccc' : esc_attr( $field_value );

						echo '<div id="cp_' . esc_attr( $field_id ) . '" class="cp_box"' . ( $field_value ? " style='background-color:" . esc_attr( $field_value ) . "; border-color:$border_color;'" : '' ) . '></div>';

					echo '</div>';

				echo '</div>';

			echo '</div>';
		}

	}
}
/**
 * Category Sidebar Select option type.
 *
 * See @ot_display_by_type to see the full list of available arguments.
 *
 * @param     array     An array of arguments.
 * @return    string
 *
 * @access    public
 * @since     2.0
 */
if ( ! function_exists( 'ot_type_category_sidebar_select' ) ) {

	function ot_type_category_sidebar_select( $args = array() ) {

		/* turns arguments array into variables */
		extract( $args );

		/* verify a description */
		$has_desc = $field_desc ? true : false;

		$args = array(
			'type'         => 'post',
			'child_of'     => 0,
			'parent'       => '',
			'orderby'      => 'name',
			'order'        => 'ASC',
			'hide_empty'   => 0,
			'hierarchical' => 0,
			'exclude'      => '',
			'include'      => '',
			'number'       => '',
			'taxonomy'     => 'category',
			'pad_counts'   => false,

		);
		global $sitepress;

		if ( $sitepress ) {
			remove_filter( 'terms_clauses', array( $sitepress, 'terms_clauses' ) );
		}
		$categories = get_terms( 'category', array( 'hide_empty' => false ) );

		/* get the registered sidebars */
		global $wp_registered_sidebars;

		$sidebars = array();
		foreach ( $wp_registered_sidebars as $id => $sidebar ) {
			$sidebars[ $id ] = $sidebar['name'];
		}

		/* filters to restrict which sidebars are allowed to be selected, for example we can restrict footer sidebars to be selectable on a blog page */
		$sidebars = apply_filters( 'ot_recognized_sidebars', $sidebars );
		$sidebars = apply_filters( 'ot_recognized_sidebars_' . $field_id, $sidebars );

		foreach ( $categories as $category ) {
			$field_id    = 'category_sidebars_' . $category->term_id;
			$field_name  = 'option_tree[category_sidebars_' . $category->term_id . ']';
			$field_value = ot_get_option( $field_id );

			/* format setting outer wrapper */
			echo '<div class="format-setting type-sidebar-select has-desc">';

				/* description */
				 echo '<div class="description">Sidebar for "' . esc_attr( $category->name ) . '"</div>';

				/* format setting inner wrapper */
				echo '<div class="format-setting-inner">';

					/* build page select */
					echo '<select name="' . esc_attr( $field_name ) . '" id="' . esc_attr( $field_id ) . '" class="option-tree-ui-select ' . $field_class . '">';

					/* has sidebars */
			if ( count( $sidebars ) ) {
				echo '<option value="">-- ' . esc_html__( 'Choose Sidebar', 'goodlife' ) . ' --</option>';
				foreach ( $sidebars as $id => $sidebar ) {
					echo '<option value="' . esc_attr( $id ) . '"' . selected( $field_value, $id, false ) . '>' . esc_attr( $sidebar ) . '</option>';
				}
			} else {
				echo '<option value="">' . esc_html__( 'No Sidebars', 'goodlife' ) . '</option>';
			}

					echo '</select>';

				echo '</div>';

			echo '</div>';
		}

	}
}

/**
 * Category Grid Select option type.
 *
 * See @ot_display_by_type to see the full list of available arguments.
 *
 * @param     array     An array of arguments.
 * @return    string
 *
 * @access    public
 * @since     2.0
 */
if ( ! function_exists( 'ot_type_category_grid_select' ) ) {

	function ot_type_category_grid_select( $args = array() ) {

		/* turns arguments array into variables */
		extract( $args );

		/* verify a description */
		$has_desc        = $field_desc ? true : false;
		$grid_choices    = $field_choices['grid'];
		$title_choices   = $field_choices['title'];
		$overlay_choices = $field_choices['overlay'];

		$categories = get_terms( 'category', array( 'hide_empty' => false ) );

		foreach ( $categories as $category ) {
			/* Grid Style */
			$grid_id    = 'category_grids_' . $category->term_id;
			$grid_name  = 'option_tree[category_grids_' . $category->term_id . ']';
			$grid_value = ot_get_option( $grid_id );

			/* Title Style */
			$title_id    = 'category_grids_title_' . $category->term_id;
			$title_name  = 'option_tree[category_grids_title_' . $category->term_id . ']';
			$title_value = ot_get_option( $title_id );

			/* Overlay Style */
			$overlay_id    = 'category_grids_overlay_' . $category->term_id;
			$overlay_name  = 'option_tree[category_grids_overlay_' . $category->term_id . ']';
			$overlay_value = ot_get_option( $overlay_id );

			/* format setting outer wrapper */
			echo '<div class="format-setting type-select ' . ( $has_desc ? 'has-desc' : 'no-desc' ) . '">';

				/* description */
				echo '<div class="description">Grid for "' . $category->name . '"</div>';

				/* filter choices array */
				$grid_choices    = apply_filters( 'ot_type_select_choices', $grid_choices, $field_id );
				$title_choices   = apply_filters( 'ot_type_select_choices', $title_choices, $field_id );
				$overlay_choices = apply_filters( 'ot_type_select_choices', $overlay_choices, $field_id );

				/* format setting inner wrapper */
				echo '<div class="format-setting-inner">';

					/* build select - 1*/
					echo '<select name="' . esc_attr( $grid_name ) . '" id="' . esc_attr( $grid_id ) . '" class="option-tree-ui-select ' . esc_attr( $field_class ) . '">';
			foreach ( (array) $grid_choices as $choice ) {
				if ( isset( $choice['value'] ) && isset( $choice['label'] ) ) {
					echo '<option value="' . esc_attr( $choice['value'] ) . '"' . selected( $grid_value, $choice['value'], false ) . '>' . esc_attr( $choice['label'] ) . '</option>';
				}
			}
					echo '</select>';
					/* build select - 2 */
					echo '<select name="' . esc_attr( $title_name ) . '" id="' . esc_attr( $title_id ) . '" class="option-tree-ui-select ' . esc_attr( $field_class ) . '">';
			foreach ( (array) $title_choices as $choice ) {
				if ( isset( $choice['value'] ) && isset( $choice['label'] ) ) {
					echo '<option value="' . esc_attr( $choice['value'] ) . '"' . selected( $title_value, $choice['value'], false ) . '>' . esc_attr( $choice['label'] ) . '</option>';
				}
			}
					echo '</select>';
					/* build select - 3 */
					echo '<select name="' . esc_attr( $overlay_name ) . '" id="' . esc_attr( $overlay_id ) . '" class="option-tree-ui-select ' . esc_attr( $field_class ) . '">';
			foreach ( (array) $overlay_choices as $choice ) {
				if ( isset( $choice['value'] ) && isset( $choice['label'] ) ) {
					echo '<option value="' . esc_attr( $choice['value'] ) . '"' . selected( $overlay_value, $choice['value'], false ) . '>' . esc_attr( $choice['label'] ) . '</option>';
				}
			}
					echo '</select>';
				echo '</div>';

			echo '</div>';

		}

	}
}
