<?php
class Thb_Theme_Admin {
	/**
	 *  Main instance
	 */
	private static $instance;

	/**
	 *  Theme Name
	 */
	public static $thb_theme_name;

	/**
	 *  Theme Version
	 */
	public static $thb_theme_version;

	/**
	 *  Theme Slug
	 */
	public static $thb_theme_slug;

	/**
	 *  Theme Directory
	 */
	public static $thb_theme_directory;

	/**
	 *  Theme Directory URL
	 */
	public static $thb_theme_directory_uri;

	/**
	 *  Product Key
	 */
	public static $thb_product_key;

	/**
	 *  Product Key Expiration
	 */
	public static $thb_product_key_expired;

	/**
	 *  Theme Constructor executed only once per request
	 */
	public function __construct() {
		if ( self::$instance ) {
			_doing_it_wrong( __FUNCTION__, 'Cheatin&#8217; huh?', '2.0' );
		}
	}

	/**
	 * You cannot clone this class
	 */
	public function __clone() {
		_doing_it_wrong( __FUNCTION__, 'Cheatin&#8217; huh?', '2.0' );
	}

	/**
	 * You cannot unserialize instances of this class
	 */
	public function __wakeup() {
		_doing_it_wrong( __FUNCTION__, 'Cheatin&#8217; huh?', '2.0' );
	}

	public static function instance() {
		global $thb_Theme_Admin;
		if ( ! self::$instance ) {
			self::$instance  = new self();
			$thb_Theme_Admin = self::$instance;

			// Theme Variables
			$theme                         = wp_get_theme();
			self::$thb_theme_name          = $theme->get( 'Name' );
			self::$thb_theme_version       = $theme->parent() ? $theme->parent()->get( 'Version' ) : $theme->get( 'Version' );
			self::$thb_theme_slug          = $theme->template;
			self::$thb_theme_directory     = get_template_directory() . '/';
			self::$thb_theme_directory_uri = get_template_directory_uri() . '/';

			self::$thb_product_key         = get_option( 'thb_' . self::$thb_theme_slug . '_key' );
			self::$thb_product_key_expired = get_option( 'thb_' . self::$thb_theme_slug . '_key_expired' );

			// After Setup Theme
			add_action( 'after_setup_theme', array( self::$instance, 'afterSetupTheme' ) );

			// Setup Admin Menus
			if ( is_admin() ) {
				self::$instance->initAdminPages();
			}
		}

		return self::$instance;
	}
	/**
	 *  After Theme Setup
	 */
	public function afterSetupTheme() {
		/* WooCommerce Support */
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'yoast-seo-breadcrumbs' );

		/* WooCommerce Products per Page */
		add_filter( 'loop_shop_per_page', 'thb_shops_per_page', 20 );

		function thb_shops_per_page( $products_per_page ) {
			$products_per_page_get = filter_input( INPUT_GET, 'products_per_page', FILTER_VALIDATE_INT );
			$products_per_page     = isset( $products_per_page_get ) ? $products_per_page_get : ot_get_option( 'products_per_page' );
			return $products_per_page;
		}

		/* Gutenberg */
		add_theme_support( 'align-wide' );
		add_theme_support( 'align-full' );
		add_theme_support(
			'editor-color-palette',
			array(
				array(
					'name'  => esc_html__( 'Accent Color', 'goodlife' ),
					'slug'  => 'thb-accent',
					'color' => ot_get_option( 'accent_color', '#f74a2e' ),
				),
			)
		);

		/* Text Domain */
		load_theme_textdomain( 'goodlife', get_stylesheet_directory() . '/inc/languages' );

		/* Background Support */
		add_theme_support( 'custom-background', array( 'default-color' => 'ffffff' ) );

		/* Title Support */
		add_theme_support( 'title-tag' );

		/* Post Formats */
		add_theme_support( 'post-formats', array( 'video', 'gallery' ) );

		/* Required Settings */
		global $content_width;
		if ( ! isset( $content_width ) ) {
			$content_width = 1170; }
		add_theme_support( 'automatic-feed-links' );

		/* Image Settings */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 160, 150, true );

		$thb_image_sizes = self::$instance->thb_image_sizes();

		// Register image size
		foreach ( $thb_image_sizes as $image_size ) {
			add_image_size( $image_size['slug'], $image_size['width'], $image_size['height'], $image_size['crop'] );
		}

		/* Image Settings */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 80, 75, true );

		if ( false === get_option( 'medium_crop' ) ) {
			add_option( 'medium_crop', '1' );
		} else {
			update_option( 'medium_crop', '1' );
		}

		/* HTML5 Galleries */
		add_theme_support( 'html5', array( 'gallery', 'caption' ) );

		/* Register Menus */
		add_theme_support( 'nav-menus' );
		register_nav_menus(
			array(
				'nav-menu'       => esc_html__( 'Navigation Menu', 'goodlife' ),
				'secondary-menu' => esc_html__( 'Secondary Menu', 'goodlife' ),
				'footer-menu'    => esc_html__( 'Footer Menu', 'goodlife' ),
				'subheader-menu' => esc_html__( 'Sub Header Menu', 'goodlife' ),
				'mobile-menu'    => esc_html__( 'Mobile Menu', 'goodlife' ),
			)
		);

		$sidebars           = ot_get_option( 'sidebars' );
		$widget_title_style = ot_get_option( 'widget_title_style', 'title-style1' );
		if ( ! empty( $sidebars ) ) {
			foreach ( $sidebars as $sidebar ) {
				register_sidebar(
					array(
						'name'          => $sidebar['title'],
						'id'            => $sidebar['id'],
						'description'   => '',
						'before_widget' => '<div id="%1$s" class="widget cf %2$s ' . esc_attr( $widget_title_style ) . '">',
						'after_widget'  => '</div>',
						'before_title'  => '<div class="widget_title"><strong>',
						'after_title'   => '</strong></div>',
					)
				);
			}
		}
		/* Add a pingback url auto-discovery header for single posts, pages, or attachments. */
		function thb_pingback_header() {
			if ( is_singular() && pings_open() ) {
				echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
			}
		}
		add_action( 'wp_head', 'thb_pingback_header' );
	}
	public function thb_image_sizes() {
		$thb_image_sizes = apply_filters(
			'thb_image_sizes_filter',
			array(
				array(
					'slug'   => 'goodlife-thumbnail',
					'width'  => 80,
					'height' => 75,
					'crop'   => true,
				),
				array(
					'slug'   => 'goodlife-grid',
					'width'  => 320,
					'height' => 270,
					'crop'   => true,
				),
				array(
					'slug'   => 'goodlife-latest',
					'width'  => 320,
					'height' => 225,
					'crop'   => true,
				),
				array(
					'slug'   => 'goodlife-latestshort',
					'width'  => 320,
					'height' => 170,
					'crop'   => true,
				),
				array(
					'slug'   => 'goodlife-vertical',
					'width'  => 320,
					'height' => 420,
					'crop'   => true,
				),
				array(
					'slug'   => 'goodlife-gallery',
					'width'  => 320,
					'height' => 150,
					'crop'   => true,
				),
				array(
					'slug'   => 'goodlife-galleryvertical',
					'width'  => 320,
					'height' => 350,
					'crop'   => true,
				),
				array(
					'slug'   => 'goodlife-poststyle1',
					'width'  => 770,
					'height' => 9999,
					'crop'   => false,
				),
			)
		);

		function thb_calculate_image_orientation( $thb_image_sizes ) {
			if ( ! is_array( $thb_image_sizes ) ) {
				return;
			}
			$new_sizes = array();
			foreach ( $thb_image_sizes as $image_size ) {
				$new_sizes[] = array(
					'slug'   => $image_size['slug'] . '-small',
					'width'  => absint( $image_size['width'] / 2 ),
					'height' => $image_size['height'] === 9999 ? 9999 : absint( $image_size['height'] * 2 ),
					'crop'   => $image_size['crop'],
				);
				$new_sizes[] = array(
					'slug'   => $image_size['slug'] . '-2x',
					'width'  => $image_size['width'] * 2,
					'height' => $image_size['height'] === 9999 ? 9999 : $image_size['height'] * 2,
					'crop'   => $image_size['crop'],
				);
				$new_sizes[] = array(
					'slug'   => $image_size['slug'] . '-mini',
					'width'  => 20,
					'height' => $image_size['height'] === 9999 ? 9999 : absint( ( $image_size['height'] * 20 ) / $image_size['width'] ),
					'crop'   => $image_size['crop'],
				);
			}
			return $new_sizes;
		}
		$new_sizes = thb_calculate_image_orientation( $thb_image_sizes );
		foreach ( $new_sizes as $new_size ) {
			$thb_image_sizes[] = $new_size;
		}
		return $thb_image_sizes;
	}
	public function thbDemos() {
		return array(
			array(
				'import_file_name'         => 'GoodLife',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodlife/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodlife/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodlife/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodlife.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/',
			),
			array(
				'import_file_name'         => 'GoodMusic',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodmusic/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodmusic/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodmusic/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodmusic.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/music-demo/',
			),
			array(
				'import_file_name'         => 'GoodGame',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodgame/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodgame/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodgame/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodgame.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/games-demo/',
			),
			array(
				'import_file_name'         => 'GoodSport',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodsport/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodsport/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodsport/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodsport.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/sports-demo/',
			),
			array(
				'import_file_name'         => 'GoodLook',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodlook/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodlook/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodlook/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodlook.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/fashion-demo/',
			),
			array(
				'import_file_name'         => 'GoodTech',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodtech/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodtech/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodtech/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodtech.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/technology-demo/',
			),
			array(
				'import_file_name'         => 'GoodBlog',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodblog/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodblog/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodblog/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodblog.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/blog-demo/',
			),
			array(
				'import_file_name'         => 'GoodTravel',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodtravel/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodtravel/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodtravel/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodtravel.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/travel-demo/',
			),
			array(
				'import_file_name'         => 'GoodNews',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodnews/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodnews/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodnews/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodnews.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/news-demo/',
			),
			array(
				'import_file_name'         => 'GoodTimes',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodtimes/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodtimes/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodtimes/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodtimes.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/times-demo/',
			),
			array(
				'import_file_name'         => 'GoodStyle',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodstyle/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodstyle/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodstyle/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodstyle.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/style-demo/',
			),
			array(
				'import_file_name'         => 'GoodCrypto',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodcrypto/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodcrypto/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodcrypto/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodcrypto.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/crypto-demo/',
			),
			array(
				'import_file_name'         => 'GoodMagazine',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodmagazine/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodmagazine/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodmagazine/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodmag.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/magazine-demo/',
			),
			array(
				'import_file_name'         => 'GoodFeed',
				'import_file_url'          => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodfeed/democontent.xml',
				'import_widget_file_url'   => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodfeed/widget_data.json',
				'import_theme_options_url' => 'http://themes.fuelthemes.net/theme-demo-files/goodlifev4/goodfeed/theme-options.txt',
				'import_image'             => self::$thb_theme_directory_uri . 'assets/img/admin/demos/homepages/goodfeed.jpg',
				'import_demo_url'          => 'https://goodlife.fuelthemes.net/feed-demo/',
			),
		);
	}
	/**
	 *  Inintialize Admin Pages
	 */
	public function initAdminPages() {
		global $pagenow;

		// Script and styles
		add_action( 'admin_enqueue_scripts', array( & $this, 'adminPageEnqueue' ) );

		// Menu Pages
		add_action( 'admin_menu', array( & $this, 'adminSetupMenu' ), 1 );

		// Theme Options Redirect
		if ( $pagenow ) {
			if ( 'admin.php' == $pagenow && isset( $_GET['page'] ) && 'thb-theme-options' == wp_unslash( $_GET['page'] ) ) {
				if ( ! ( defined( 'WP_CLI' ) && WP_CLI ) ) {
					wp_redirect( admin_url( 'themes.php?page=ot-theme-options' ) );
					die();
				}
			}
		}

		// Redirect to Main Page
		add_action( 'after_switch_theme', array( & $this, 'thb_activation_redirect' ) );

		// Ajax Option Update
		add_action( 'wp_ajax_thb_update_options', array( & $this, 'thb_update_options' ) );
		add_action( 'wp_ajax_nopriv_thb_update_options', array( & $this, 'thb_update_options' ) );

		// Admin Notices
		add_action( 'admin_notices', array( & $this, 'thb_admin_notices' ) );

		// Theme Updates
		add_action( 'admin_init', array( & $this, 'thb_theme_update' ) );

		// Plugin Update Nonce
		add_action( 'register_sidebar', array( & $this, 'thb_theme_admin_init' ) );

	}
	function thb_admin_notices() {
		$remote_ver = get_option( 'thb_' . self::$thb_theme_slug . '_remote_ver' ) ? get_option( 'thb_' . self::$thb_theme_slug . '_remote_ver' ) : self::$thb_theme_version;
		$local_ver  = self::$thb_theme_version;

		if ( version_compare( $local_ver, $remote_ver, '<' ) ) {
			if (
				( ! self::$thb_product_key && ( self::$thb_product_key_expired == 0 ) ) ||
				( self::$thb_product_key && ( self::$thb_product_key_expired == 1 ) )
			) {
				echo '<div class="notice is-dismissible error thb_admin_notices">
				<p>There is an update available for the <strong>' . self::$thb_theme_name . '</strong> theme. Go to <a href="' . esc_url( admin_url( 'admin.php?page=thb-product-registration' ) ) . '">Product Registration</a> to enable theme updates.</p>
				</div>';
			}

			if ( ( self::$thb_product_key && ( self::$thb_product_key_expired == 0 ) ) ) {
				echo '<div class="notice is-dismissible error thb_admin_notices">
				<p>There is an update available for the <strong>' . self::$thb_theme_name . '</strong> theme. <a href="' . esc_url( admin_url() ) . 'update-core.php">Update now</a>.</p>
				</div>';
			}
		}
	}
	public function thb_update_options() {
		check_ajax_referer( 'thb_register_ajax', 'security' );
		$key     = filter_input( INPUT_POST, 'key', FILTER_SANITIZE_STRING );
		$expired = filter_input( INPUT_POST, 'expired', FILTER_VALIDATE_BOOLEAN );
		update_option( 'thb_' . self::$thb_theme_slug . '_key', $key );
		update_option( 'thb_' . self::$thb_theme_slug . '_key_expired', $expired );
	}
	public function thb_theme_update() {
		add_filter( 'pre_set_site_transient_update_themes', array( & $this, 'thb_check_for_update_theme' ) );
		add_filter( 'upgrader_pre_download', array( $this, 'thb_upgradeFilter' ), 10, 4 );
	}
	public function thb_check_for_update_plugins() {
		$name = 'thb_' . self::$thb_theme_slug . '_plugin_transient';
		$data = get_transient( $name );
		if ( ! $data ) {
			$args = array(
				'timeout' => 30,
				'body'    => array(
					'item_ids'    => '242431,11178623,2781350,7563340',
					'product_key' => self::$thb_product_key,
				),
			);

			$request = wp_remote_get( self::$instance->thb_dashboard_url( 'plugin/version' ), $args );

			$data = '';
			if ( ! is_wp_error( $request ) || wp_remote_retrieve_response_code( $request ) === 200 ) {
				$data = json_decode( wp_remote_retrieve_body( $request ) );
			}
			set_transient( $name, $data, 6 * HOUR_IN_SECONDS );
		}
		return $data;
	}
	public function thb_check_for_update_theme( $transient ) {
		global $wp_filesystem;
		$args = array(
			'timeout' => 30,
			'body'    => array(
				'theme_name'  => self::$thb_theme_name,
				'product_key' => self::$thb_product_key,
			),
		);

		$request = wp_remote_get( self::$instance->thb_dashboard_url( 'version' ), $args );

		if ( ! is_wp_error( $request ) || wp_remote_retrieve_response_code( $request ) === 200 ) {
			$data = json_decode( wp_remote_retrieve_body( $request ) );
			update_option( 'thb_' . self::$thb_theme_slug . '_key_expired', 0 );

			if ( isset( $data->success ) && false === $data->success ) {
				self::$thb_product_key_expired = 1;
				update_option( 'thb_' . self::$thb_theme_slug . '_key_expired', 1 );
			} else {
				if ( version_compare( self::$thb_theme_version, $data->version, '<' ) ) {
					$transient->response[ self::$thb_theme_slug ] = array(
						'new_version' => $data->version,
						'package'     => $data->download_url,
						'url'         => 'http://fuelthemes.net',
					);

					update_option( 'thb_' . self::$thb_theme_slug . '_remote_ver', $data->version );
				}
			}
		}
		return $transient;
	}
	public function thb_upgradeFilter( $reply, $package, $updater ) {
		global $wp_filesystem;
		$cond = ( ! self::$thb_product_key || ( self::$thb_product_key_expired == 1 ) );

		if ( isset( $updater->skin->theme_info ) && $updater->skin->theme_info['Name'] == self::$thb_theme_name ) {
			if ( $cond ) {
				return new WP_Error( 'no_credentials', sprintf( __( 'To receive automatic updates, registration is required. Please visit <a href="%1$s" target="_blank">Product Registration</a> to activate your theme.', 'goodlife' ), esc_url( admin_url( 'admin.php?page=thb-product-registration' ) ) ) );
			}
		}

		// VisualComposer
		if ( ( isset( $updater->skin->plugin ) ) && ( $updater->skin->plugin == 'js_composer/js_composer.php' ) ) {
			if ( $cond ) {
				return new WP_Error( 'no_credentials', sprintf( __( 'To receive automatic updates, registration is required. Please visit <a href="%1$s" target="_blank">Product Registration</a> to activate your theme.', 'goodlife' ), esc_url( admin_url( 'admin.php?page=thb-product-registration' ) ) ) );
			}
		}
		return $reply;
	}
	public function thb_plugins_install( $item ) {
		if ( ! function_exists( 'get_plugins' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
		}
		$installed_plugins = get_plugins();

		$item['sanitized_plugin'] = $item['name'];

		// WordPress Repository
		if ( ! $item['version'] ) {
			$item['version'] = TGM_Plugin_Activation::$instance->does_plugin_have_update( $item['slug'] );
		}

		// Install Link
		if ( ! isset( $installed_plugins[ $item['file_path'] ] ) ) {
			$actions = array(
				'install' => sprintf(
					'<a href="%1$s" class="button" title="Install %2$s">Install Now</a>',
					esc_url(
						wp_nonce_url(
							add_query_arg(
								array(
									'page'          => urlencode( TGM_Plugin_Activation::$instance->menu ),
									'plugin'        => urlencode( $item['slug'] ),
									'plugin_name'   => urlencode( $item['sanitized_plugin'] ),
									'tgmpa-install' => 'install-plugin',
									'return_url'    => network_admin_url( 'admin.php?page=thb-plugins' ),
								),
								TGM_Plugin_Activation::$instance->get_tgmpa_url()
							),
							'tgmpa-install',
							'tgmpa-nonce'
						)
					),
					$item['sanitized_plugin']
				),
			);
		}
		// Activate Link
		elseif ( is_plugin_inactive( $item['file_path'] ) ) {
			$actions = array(
				'activate' => sprintf(
					'<a href="%1$s" class="button button-primary" title="Activate %2$s">Activate</a>',
					esc_url(
						add_query_arg(
							array(
								'plugin'             => urlencode( $item['slug'] ),
								'plugin_name'        => urlencode( $item['sanitized_plugin'] ),
								'thb-activate'       => 'activate-plugin',
								'thb-activate-nonce' => wp_create_nonce( 'thb-activate' ),
								'return_url'         => network_admin_url( 'admin.php?page=thb-plugins' ),
							),
							admin_url( 'admin.php?page=thb-plugins' )
						)
					),
					$item['sanitized_plugin']
				),
			);
		}
		// Update Link

		elseif ( version_compare( $installed_plugins[ $item['file_path'] ]['Version'], $item['version'], '<' ) ) {
			$actions = array(
				'update' => sprintf(
					'<a href="%1$s" class="button button-update" title="Install %2$s"><span class="dashicons dashicons-update"></span> Update</a>',
					wp_nonce_url(
						add_query_arg(
							array(
								'page'         => urlencode( TGM_Plugin_Activation::$instance->menu ),
								'plugin'       => urlencode( $item['slug'] ),
								'tgmpa-update' => 'update-plugin',
								'version'      => urlencode( $item['version'] ),
								'return_url'   => network_admin_url( 'admin.php?page=thb-plugins' ),
							),
							TGM_Plugin_Activation::$instance->get_tgmpa_url()
						),
						'tgmpa-update',
						'tgmpa-nonce'
					),
					$item['sanitized_plugin']
				),
			);
		} elseif ( self::$instance->thb_ispluginactive( $item['file_path'] ) ) {
			$actions = array(
				'deactivate' => sprintf(
					'<a href="%1$s" class="button" title="Deactivate %2$s">Deactivate</a>',
					esc_url(
						add_query_arg(
							array(
								'plugin'               => urlencode( $item['slug'] ),
								'plugin_name'          => urlencode( $item['sanitized_plugin'] ),
								// 'plugin_source'          => urlencode( $item['source'] ),
								'thb-deactivate'       => 'deactivate-plugin',
								'thb-deactivate-nonce' => wp_create_nonce( 'thb-deactivate' ),
							),
							admin_url( 'admin.php?page=thb-plugins' )
						)
					),
					$item['sanitized_plugin']
				),
			);
		}

		return $actions;
	}
	public function thb_theme_admin_init() {
		$get_name = filter_input( INPUT_GET, 'plugin_name', FILTER_SANITIZE_STRING );

		if ( isset( $_GET['thb-deactivate'] ) && $_GET['thb-deactivate'] == 'deactivate-plugin' ) {

			check_admin_referer( 'thb-deactivate', 'thb-deactivate-nonce' );

			if ( ! function_exists( 'get_plugins' ) ) {
				require_once ABSPATH . 'wp-admin/includes/plugin.php';
			}

			$plugins = get_plugins();

			foreach ( $plugins as $plugin_name => $plugin ) {
				if ( $plugin['Name'] == $get_name ) {
						deactivate_plugins( $plugin_name );
				}
			}
		}

		if ( isset( $_GET['thb-activate'] ) && $_GET['thb-activate'] == 'activate-plugin' ) {

			check_admin_referer( 'thb-activate', 'thb-activate-nonce' );

			if ( ! function_exists( 'get_plugins' ) ) {
				require_once ABSPATH . 'wp-admin/includes/plugin.php';
			}

			$plugins = get_plugins();

			foreach ( $plugins as $plugin_name => $plugin ) {
				if ( $plugin['Name'] == $get_name ) {
					activate_plugin( $plugin_name );
				}
			}
		}

	}
	public function thb_activation_redirect() {
		if ( ! ( defined( 'WP_CLI' ) && WP_CLI ) ) {
			$goodlife_installed = 'goodlife_installed';

			if ( false == get_option( $goodlife_installed, false ) ) {
				update_option( $goodlife_installed, true );
				wp_redirect( admin_url( 'admin.php?page=thb-product-registration' ) );
				die();
			}

			delete_option( $goodlife_installed );
		}
	}
	public function adminPageEnqueue() {
		wp_enqueue_script( 'thb-admin-meta', self::$thb_theme_directory_uri . 'assets/js/admin-meta.min.js', array( 'jquery' ), esc_attr( self::$thb_theme_version ) );
		wp_enqueue_style( 'thb-admin-css', self::$thb_theme_directory_uri . 'assets/css/admin.css', null, esc_attr( self::$thb_theme_version ) );
		wp_enqueue_style( 'thb-admin-vs-css', self::$thb_theme_directory_uri . 'assets/css/admin_vc.css', null, esc_attr( self::$thb_theme_version ) );

		if ( class_exists( 'WPBakeryVisualComposerAbstract' ) ) {
			wp_enqueue_style( 'vc_extra_css', self::$thb_theme_directory_uri . 'assets/css/vc_extra.css' );
			wp_enqueue_script( 'thb-admin-vc', self::$thb_theme_directory_uri . 'assets/js/admin-vc.min.js', array( 'jquery' ), esc_attr( self::$thb_theme_version ) );
		}
		wp_enqueue_media();
	}
	public function adminSetupMenu() {

		// Product Registration
		add_menu_page( self::$thb_theme_name, self::$thb_theme_name, 'edit_theme_options', 'thb-product-registration', array( & $this, 'thb_Product_Registration' ), self::$thb_theme_directory_uri . 'assets/img/admin/fuelthemes-icon.svg', 3 );

		// Product Registration
		add_submenu_page( 'thb-product-registration', 'Registration', 'Registration', 'edit_theme_options', 'thb-product-registration', array( & $this, 'thb_Product_Registration' ) );

		// Main Menu Item
		add_submenu_page( 'thb-product-registration', 'Plugins', 'Plugins', 'edit_theme_options', 'thb-plugins', array( & $this, 'thb_Plugins' ) );

		// Demo Import
		add_submenu_page( 'thb-product-registration', 'Demo Import', 'Demo Import', 'edit_theme_options', 'thb-demo-import', array( & $this, 'thb_Demo_Import' ) );

		// Theme Options
		add_submenu_page( 'thb-product-registration', 'Theme Options', 'Theme Options', 'edit_theme_options', 'thb-theme-options', '__return_false' );

	}
	public function thb_Plugins() {
		get_template_part( 'inc/admin/welcome/pages/plugins' );
	}
	public function thb_Product_Registration() {
		get_template_part( 'inc/admin/welcome/pages/registration' );
	}
	public function thb_Demo_Import() {
		get_template_part( 'inc/admin/welcome/pages/demo-import' );
	}
	public function thb_ispluginactive( $value ) {
		$func = 'is_plugin' . '_active';
		return $func( $value );
	}
	/**
	 *  Inintialize API
	 */
	public function thb_dashboard_url( $type = null ) {
		$url = 'https://my.fuelthemes.net';
		switch ( $type ) {
			case 'verify':
				$url .= '/api/verify';
				break;
			case 'verify-by-purchase':
				$url .= '/api/verify-by-purchase';
				break;
			case 'version':
				$url .= '/api/version';
				break;
			case 'plugin/version':
				$url .= '/api/plugin/version';
				break;
			case 'demo':
				$url .= '/api/demo';
				break;
		}
		return $url;
	}
}
// Main instance shortcut
function thb_Theme_Admin() {
	global $thb_Theme_Admin;
	return $thb_Theme_Admin;
}
Thb_Theme_Admin::instance();
