<?php
add_action( 'wp_ajax_nopriv_thb_ajax_cat', 'thb_ajax_cat' );
add_action( 'wp_ajax_thb_ajax_cat', 'thb_ajax_cat' );

function thb_ajax_cat() {
	check_ajax_referer( 'thb_ajax_cat', 'security' );
	$style = filter_input( INPUT_POST, 'style', FILTER_SANITIZE_STRING );
	$catid = filter_input( INPUT_POST, 'catid', FILTER_VALIDATE_INT );

	switch ( $style ) {
		case 'style1':
			$ppp = 6;
			break;
		case 'style2':
			$ppp = 7;
			break;
		case 'style3':
			$ppp = 10;
			break;
		case 'style4':
			$ppp = 5;
			break;
		case 'style5':
			$ppp = 3;
			break;
		case 'style6':
			$ppp = 3;
			break;
		case 'style6-fashion':
			$ppp = 3;
			break;
		case 'style7':
			$ppp = 5;
			break;
		case 'style8':
			$ppp = 5;
			break;
		case 'style9':
			$ppp = 6;
			break;
		case 'style10':
			$ppp = 5;
			break;
		case 'style11':
			$ppp = 6;
			break;
	}

	$args       = array(
		'cat'                 => $catid,
		'post_type'           => 'post',
		'post_status'         => 'publish',
		'posts_per_page'      => $ppp,
		'ignore_sticky_posts' => 1,
		'no_found_rows'       => true,
	);
	$ajax_posts = new WP_Query( $args );
	$item_count = $ajax_posts->post_count;

	$ids = wp_list_pluck( $ajax_posts->posts, 'ID' );
		thb_DisplayCategoryBlock( $style, $ids, $ppp );
	wp_die();
}

add_action( 'wp_ajax_nopriv_thb_listing', 'thb_listing' );
add_action( 'wp_ajax_thb_listing', 'thb_listing' );

function thb_listing() {
	check_ajax_referer( 'thb_listing_ajax', 'security' );

	$count = filter_input( INPUT_POST, 'count', FILTER_VALIDATE_INT );
	$type  = filter_input( INPUT_POST, 'type', FILTER_SANITIZE_STRING );
	$time  = filter_input( INPUT_POST, 'time', FILTER_SANITIZE_STRING );
	if ( $type === 'comments' ) {
		$args = array(
			'post_type'           => 'post',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => 1,
			'no_found_rows'       => true,
			'posts_per_page'      => $count,
			'orderby'             => 'comment_count',
			'order'               => 'DESC',
		);
		if ( $time === '7' ) {
			$args['date_query'] = array(
				array(
					'after' => '1 week ago',
				),
			);
		} elseif ( $time === '30' ) {
			$args['date_query'] = array(
				array(
					'after' => '1 month ago',
				),
			);
		} elseif ( $time === '365' ) {
			$args['date_query'] = array(
				array(
					'after' => '1 year ago',
				),
			);
		}
		$postmeta = array( false, false, true, false );

		$query = new WP_Query( $args );

		if ( ! $query->found_posts ) {
			$query = new WP_Query(
				array(
					'post_type'           => 'post',
					'post_status'         => 'publish',
					'ignore_sticky_posts' => 1,
					'no_found_rows'       => true,
					'posts_per_page'      => $count,
				)
			);
		}
	} elseif ( $type === 'views' ) {

		$post_views = thb_most_viewed( $time, $count );

		$post_ids = array_map(
			function( $n ) {
				return $n['post_id'];
			},
			$post_views
		);

		$args  = array(
			'post_type'      => 'post',
			'post_status'    => 'publish',
			'no_found_rows'  => true,
			'post__in'       => $post_ids,
			'orderby'        => 'post__in',
			'posts_per_page' => $count,
		);
		$query = new WP_Query( $args );
	}
	$counts = 0;
	if ( $query->have_posts() ) :
		while ( $query->have_posts() ) :
			$query->the_post();
			$counts++;
			set_query_var( 'counts', $counts );
			if ( $type === 'views' ) {
				$key      = array_search( get_the_ID(), array_column( $post_views, 'post_id' ) );
				$postmeta = array( false, false, false, $post_views[ $key ]['views'] );
			}
			set_query_var( 'postmeta', $postmeta );
			get_template_part( 'inc/templates/post-styles/thumbnail-listing' );
	endwhile;
		set_query_var( 'counts', false ); else :
				get_template_part( 'inc/templates/loop/notfound-list' );
	endif;
		wp_die();
}
add_action( 'wp_ajax_thb-parse-embed', 'thb_ajax_parse_embed', 1 );
add_action( 'wp_ajax_nopriv_thb-parse-embed', 'thb_ajax_parse_embed', 1 );

function thb_ajax_parse_embed() {
	check_ajax_referer( 'thb_video_playlist', 'security' );
	$id       = filter_input( INPUT_POST, 'post_ID', FILTER_VALIDATE_INT );
	$thb_post = get_post( $id );
	if ( ! $thb_post ) {
		wp_send_json_error();
	}
	$video_url = get_post_meta( $id, 'post_video', true );
	if ( '' !== $video_url && wp_oembed_get( $video_url ) ) {
		$parsed = '<div class="flex-video widescreen">' . wp_oembed_get( $video_url ) . '</div>';
	} else {
		$parsed = wp_video_shortcode(
			array(
				'src' => $video_url,
			)
		);
	}
	wp_send_json_success(
		array(
			'body' => $parsed,
		)
	);
}
add_action( 'wp_ajax_nopriv_thb_posts', 'thb_posts' );
add_action( 'wp_ajax_thb_posts', 'thb_posts' );

function thb_posts() {
	check_ajax_referer( 'thb_posts_ajax', 'security' );
	$style        = filter_input( INPUT_POST, 'style', FILTER_SANITIZE_STRING );
	$loop         = filter_input( INPUT_POST, 'loop', FILTER_SANITIZE_STRING );
	$page         = filter_input( INPUT_POST, 'page', FILTER_SANITIZE_STRING );
	$columns      = filter_input( INPUT_POST, 'columns', FILTER_VALIDATE_INT );
	$thb_excerpts = filter_input( INPUT_POST, 'excerpts', FILTER_SANITIZE_STRING );

	$source_data          = VcLoopSettings::parseData( $loop );
	$source_data['paged'] = $page;
	$source_data          = thb_moveKeyBefore( $source_data, 'offset', 'paged' );
	$query_builder        = new ThbLoopQueryBuilder( $source_data );
	$thb_posts            = $query_builder->build();
	$thb_posts            = $thb_posts[1];

	ob_start();
	$col = thb_getColumns( $columns );
	add_filter( 'wp_get_attachment_image_attributes', 'thb_lazy_low_quality', 10, 3 );
	if ( $thb_posts->have_posts() ) :
		while ( $thb_posts->have_posts() ) :
			$thb_posts->the_post();
			if ( $style === 'style1' ) { ?>
			<div class="small-12 columns"><?php get_template_part( 'inc/templates/post-styles/style2' ); ?></div>
			<?php } elseif ( $style === 'style2' ) { ?>
			<div class="<?php echo esc_attr( $col ); ?> columns">
								   <?php
									set_query_var( 'thb_excerpts', $thb_excerpts );
									get_template_part( 'inc/templates/post-styles/style3' );
									?>
			</div>
		<?php } elseif ( $style === 'style3' ) { ?>
			<div class="small-12 columns"><?php get_template_part( 'inc/templates/post-styles/style4' ); ?></div>
		<?php } elseif ( $style === 'style4' ) { ?>
			<div class="<?php echo esc_attr( $col ); ?> columns">
								   <?php
									set_query_var( 'thb_excerpts', $thb_excerpts );
									get_template_part( 'inc/templates/post-styles/style3-alt' );
									?>
			</div>
		<?php } elseif ( $style === 'style5' ) { ?>
			<div class="<?php echo esc_attr( $col ); ?> columns"><?php get_template_part( 'inc/templates/post-styles/style5' ); ?></div>
		<?php } elseif ( $style === 'style6' ) { ?>
			<div class="<?php echo esc_attr( $col ); ?> columns"><?php	get_template_part( 'inc/templates/post-styles/style5' ); ?></div>
		<?php } elseif ( $style === 'style7' ) { ?>
			<div class="small-12 columns"><?php get_template_part( 'inc/templates/post-styles/style2' ); ?></div>
		<?php } elseif ( $style === 'style8' ) { ?>
			<div class="small-12 columns"> <?php get_template_part( 'inc/templates/post-styles/style6' ); ?></div>
		<?php } elseif ( $style === 'style9' ) { ?>
			<div class="<?php echo esc_attr( $col ); ?> columns"><?php get_template_part( 'inc/templates/post-styles/style6-vertical' ); ?></div>
			<?php
		}
	endwhile;
endif;
	$out = ob_get_contents();
	$out = preg_replace( '/(\>)\s*(\<)/m', '$1$2', $out );
	if ( $out ) {
		ob_end_clean(); }

	echo $out;
	wp_die();
}

add_action( 'wp_ajax_nopriv_thb_infinite_ajax', 'thb_infinite_ajax' );
add_action( 'wp_ajax_thb_infinite_ajax', 'thb_infinite_ajax' );

function thb_infinite_ajax() {
	check_ajax_referer( 'thb_infinite_ajax', 'security' );
	global $post;
	$id            = filter_input( INPUT_POST, 'post_id', FILTER_VALIDATE_INT );
	$post          = get_post( $id );
	$previous_post = get_previous_post();

	if ( $id ) {
		$args  = array(
			'p'              => $previous_post->ID,
			'no_found_rows'  => true,
			'posts_per_page' => 1,
			'post_status'    => 'publish',
		);
		$query = new WP_Query( $args );
		ob_start();
		do_action( 'thb_vc_ajax' );
		add_filter( 'wp_get_attachment_image_attributes', 'thb_lazy_low_quality', 10, 3 );
		if ( $query->have_posts() ) :
			while ( $query->have_posts() ) :
				$query->the_post();
				global $more;
				$more   = -1;

				set_query_var( 'thb_ajax', true );

				$thb_id = get_the_ID();
				$format = get_post_format();
				if ( 'video' === $format ) {
					$video_article_style_override = get_post_meta( $thb_id, 'video_article_style_override', true );
					if ( 'on' === $video_article_style_override || '' === $video_article_style_override ) {
						$post_meta_style = get_post_meta( $thb_id, 'video-post-detail-style', true );
						$post_style      = '' !== $post_meta_style ? $post_meta_style : 'style1';
					} else {
						$post_style = ot_get_option( 'video-post-detail-style', 'style1' );
					}
					get_template_part( 'inc/templates/post-detail-styles/' . $format . '-' . $post_style );
				} elseif ( 'gallery' === $format ) {
					$gallery_article_style_override = get_post_meta( $thb_id, 'gallery_article_style_override', true );

					if ( 'on' === $gallery_article_style_override || '' === $gallery_article_style_override ) {
						$post_meta_style = get_post_meta( $thb_id, 'gallery-post-detail-style', true );
						$post_style      = '' !== $post_meta_style ? $post_meta_style : 'style1';
					} else {
						$post_style = ot_get_option( 'gallery-post-detail-style', 'style1' );
					}
					get_template_part( 'inc/templates/post-detail-styles/' . $format . '-' . $post_style );
				} else {
					$standard_article_style_override = get_post_meta( $thb_id, 'standard_article_style_override', true );
					if ( 'on' === $standard_article_style_override || '' === $standard_article_style_override ) {
						$post_meta_style = get_post_meta( $thb_id, 'standard-post-detail-style', true );
						$post_style      = '' !== $post_meta_style ? $post_meta_style : 'style1';
					} else {
						$post_style = ot_get_option( 'standard-post-detail-style', 'style1' );
					}
					get_template_part( 'inc/templates/post-detail-styles/' . $post_style );
				}
		endwhile;
endif;
		$out = ob_get_clean();
		echo $out;
	}
	wp_die();
}

/* Login Register */
add_action( 'wp_ajax_nopriv_thb_login_member', 'thb_login_member' );
add_action( 'wp_ajax_thb_login_member', 'thb_login_member' );
add_action( 'wp_ajax_nopriv_thb_register_member', 'thb_register_member' );
add_action( 'wp_ajax_thb_register_member', 'thb_register_member' );
add_action( 'wp_ajax_nopriv_thb_reset_password', 'thb_reset_password' );
add_action( 'wp_ajax_thb_reset_password', 'thb_reset_password' );

function thb_login_member() {
	// Get variables
	$user_login = filter_input( INPUT_POST, 'thb_user_login', FILTER_SANITIZE_STRING );
	$user_pass  = filter_input( INPUT_POST, 'thb_user_pass', FILTER_SANITIZE_STRING );

	// Check CSRF token
	if ( ! check_ajax_referer( 'ajax-login-nonce', 'login-security', false ) ) {
		echo wp_json_encode(
			array(
				'error'   => true,
				'message' => '<div class="alert alert-danger">' . __(
					'Session token has expired, please reload the page and try again',
					'goodlife'
				) . '</div>',
			)
		);
	}

	// Check if input variables are empty
	elseif ( empty( $user_login ) || empty( $user_pass ) ) {
		echo wp_json_encode(
			array(
				'error'   => true,
				'message' => '<div class="alert alert-danger">' . __(
					'Please fill all form fields',
					'goodlife'
				) . '</div>',
			)
		);
	} else { // Now we can insert this account

		$user = wp_signon(
			array(
				'user_login'    => $user_login,
				'user_password' => $user_pass,
			),
			false
		);

		if ( is_wp_error( $user ) ) {
			echo wp_json_encode(
				array(
					'error'   => true,
					'message' => '<div class="alert alert-danger">' . $user->get_error_message() . '</div>',
				)
			);
		} else {
			echo wp_json_encode(
				array(
					'error'   => false,
					'message' => '<div class="alert alert-success">' . __(
						'Login successful, reloading page...',
						'goodlife'
					) . '</div>',
				)
			);
		}
	}

	wp_die();
}
function thb_register_member() {
	// Get variables
	$user_login = filter_input( INPUT_POST, 'thb_user_login', FILTER_SANITIZE_STRING );
	$user_email = filter_input( INPUT_POST, 'thb_user_email', FILTER_VALIDATE_EMAIL );

	// Check CSRF token
	if ( ! check_ajax_referer( 'ajax-login-nonce', 'register-security', false ) ) {
		echo wp_json_encode(
			array(
				'error'   => true,
				'message' => '<div class="alert alert-danger">' . esc_html__(
					'Session token has expired, please reload the page and try again',
					'goodlife'
				) . '</div>',
			)
		);
		wp_die();
	}

	// Check if input variables are empty
	elseif ( empty( $user_login ) || empty( $user_email ) ) {
		echo wp_json_encode(
			array(
				'error'   => true,
				'message' => '<div class="alert alert-danger">' . esc_html__(
					'Please fill all form fields',
					'goodlife'
				) . '</div>',
			)
		);
		wp_die();
	}

	$errors = register_new_user( $user_login, $user_email );

	if ( is_wp_error( $errors ) ) {

		$registration_error_messages = $errors->errors;

		$display_errors = '<div class="alert alert-danger">';

		foreach ( $registration_error_messages as $error ) {
			$display_errors .= '<p>' . $error[0] . '</p>';
		}

		$display_errors .= '</div>';

		echo wp_json_encode(
			array(
				'error'   => true,
				'message' => $display_errors,
			)
		);

	} else {
		echo wp_json_encode(
			array(
				'error'   => false,
				'message' => '<div class="alert alert-success">' . esc_html__(
					'Registration complete. Please check your e-mail.',
					'goodlife'
				) . '</p>',
			)
		);
	}

	wp_die();
}
function thb_reset_password() {
	// Get variables
	$username_or_email = filter_input( INPUT_POST, 'thb_user_or_email', FILTER_SANITIZE_STRING );

	// Check CSRF token
	if ( ! check_ajax_referer( 'ajax-login-nonce', 'password-security', false ) ) {
		echo wp_json_encode(
			array(
				'error'   => true,
				'message' => '<div class="alert alert-danger">' . __(
					'Session token has expired, please reload the page and try again',
					'goodlife'
				) . '</div>',
			)
		);
	}

	// Check if input variables are empty
	elseif ( empty( $username_or_email ) ) {
		echo wp_json_encode(
			array(
				'error'   => true,
				'message' => '<div class="alert alert-danger">' . __(
					'Please fill all form fields',
					'goodlife'
				) . '</div>',
			)
		);
	} else {

		$username = is_email( $username_or_email ) ? sanitize_email( $username_or_email ) : sanitize_user( $username_or_email );

		$user_forgotten = thb_lostPassword_retrieve( $username );

		if ( is_wp_error( $user_forgotten ) ) {

			$lostpass_error_messages = $user_forgotten->errors;

			$display_errors = '<div class="alert alert-warning">';
			foreach ( $lostpass_error_messages as $error ) {
				$display_errors .= '<p>' . $error[0] . '</p>';
			}
			$display_errors .= '</div>';

			echo wp_json_encode(
				array(
					'error'   => true,
					'message' => $display_errors,
				)
			);
		} else {
			echo wp_json_encode(
				array(
					'error'   => false,
					'message' => '<p class="alert alert-success">' . __(
						'Password Reset. Please check your email.',
						'goodlife'
					) . '</p>',
				)
			);
		}
	}
	wp_die();
}
function thb_lostPassword_retrieve( $user_input ) {
	global $wpdb, $wp_hasher;

	$errors = new WP_Error();

	if ( empty( $user_input ) ) {
		$errors->add( 'empty_username', __( '<strong>ERROR</strong>: Enter a username or email address.', 'goodlife' ) );
	} elseif ( strpos( $user_input, '@' ) ) {
		$user_data = get_user_by( 'email', trim( $user_input ) );
		if ( empty( $user_data ) ) {
			$errors->add( 'invalid_email', __( '<strong>ERROR</strong>: There is no user registered with that email address.', 'goodlife' ) );
		}
	} else {
		$login     = trim( $user_input );
		$user_data = get_user_by( 'login', $login );
	}

	/**
	 * Fires before errors are returned from a password reset request.
	 *
	 * @param WP_Error $errors A WP_Error object containing any errors generated
	 *                         by using invalid credentials.
	 */
	do_action( 'lostpassword_post', $errors );

	if ( $errors->get_error_code() ) {
		return $errors;
	}

	if ( ! $user_data ) {
		$errors->add( 'invalidcombo', __( '<strong>ERROR</strong>: Invalid username or email.', 'goodlife' ) );
		return $errors;
	}

	// Redefining user_login ensures we return the right case in the email.
	$user_login = $user_data->user_login;
	$user_email = $user_data->user_email;
	$key        = get_password_reset_key( $user_data );

	if ( is_wp_error( $key ) ) {
		return $key;
	}

	$message  = __( 'Someone has requested a password reset for the following account:', 'goodlife' ) . "\r\n\r\n";
	$message .= network_home_url( '/' ) . "\r\n\r\n";
	$message .= sprintf( __( 'Username: %s', 'goodlife' ), $user_login ) . "\r\n\r\n";
	$message .= __( 'If this was a mistake, just ignore this email and nothing will happen.', 'goodlife' ) . "\r\n\r\n";
	$message .= __( 'To reset your password, visit the following address:', 'goodlife' ) . "\r\n\r\n";
	$message .= '<' . network_site_url( "wp-login.php?action=rp&key=$key&login=" . rawurlencode( $user_login ), 'login' ) . ">\r\n";

	if ( is_multisite() ) {
		$blogname = $GLOBALS['current_site']->site_name;
	} else { /*
		 * The blogname option is escaped with esc_html on the way into the database
		 * in sanitize_option we want to reverse this for the plain text arena of emails.
		 */
		$blogname = wp_specialchars_decode( get_option( 'blogname' ), ENT_QUOTES );
	}

	$title = sprintf( __( '[%s] Password Reset', 'goodlife' ), $blogname );

	/**
	 * Filter the subject of the password reset email.
	 *
	 * @param string  $title      Default email title.
	 * @param string  $user_login The username for the user.
	 * @param WP_User $user_data  WP_User object.
	 */
	$title = apply_filters( 'retrieve_password_title', $title, $user_login, $user_data );

	/**
	 * Filter the message body of the password reset mail.
	 *
	 * @param string  $message    Default mail message.
	 * @param string  $key        The activation key.
	 * @param string  $user_login The username for the user.
	 * @param WP_User $user_data  WP_User object.
	 */
	$message = apply_filters( 'retrieve_password_message', $message, $key, $user_login, $user_data );

	if ( $message && ! wp_mail( $user_email, wp_specialchars_decode( $title ), $message ) ) {
		$errors->add( 'mailfailed', __( '<strong>ERROR</strong>: The email could not be sent. Possible reason: your host may have disabled the mail() function.', 'goodlife' ) );
	}

	return true;
}

/* Email Subscribe */
add_action( 'wp_ajax_nopriv_thb_subscribe_emails', 'thb_subscribe_emails' );
add_action( 'wp_ajax_thb_subscribe_emails', 'thb_subscribe_emails' );

function thb_subscribe_emails() {
	check_ajax_referer( 'thb_subscription', 'security' );
	// the email
	$email = filter_input( INPUT_POST, 'email', FILTER_SANITIZE_EMAIL );

	// if the email is valid
	if ( is_email( $email ) ) {

		// get all the current emails
		$stack = get_option( 'subscribed_emails' );

		// if there are no emails in the database
		if ( ! $stack ) {
			// update the option with the first email as an array
			update_option( 'subscribed_emails', array( $email ) );
		} else {
			// if the email already exists in the array
			if ( in_array( $email, $stack ) ) {
				echo '<div class="woocommerce-error">' . __( '<strong>Oh snap!</strong> That email address is already subscribed!', 'goodlife' ) . '</div>';
			} else {

				// If there is more than one email, add the new email to the array
				array_push( $stack, $email );

				// update the option with the new set of emails
				update_option( 'subscribed_emails', $stack );

				echo '<div class="woocommerce-message">' . __( '<strong>Well done!</strong> Your address has been added', 'goodlife' ) . '</div>';
			}
		}
	} else {
		echo '<div class="woocommerce-error">' . __( '<strong>Oh snap!</strong> Please enter a valid email address', 'goodlife' ) . '</div>';
	}
	wp_die();
}
