<?php
class thb_AMP_Menu_Walker extends Walker_Nav_Menu {

	protected $thb_started_el       = false;
	protected $thb_child_started_el = false;


	function end_lvl( &$output, $depth = 0, $args = array() ) {

		$indent  = str_repeat( "\t", $depth );
		$output .= "$indent</ul>\n";

		if ( $this->thb_child_started_el && $depth == 0 ) {
			$output                    .= '</div>';
			$this->thb_child_started_el = false;
		}

		if ( $this->thb_started_el && $depth == 0 ) {
			$output              .= '</section></amp-accordion>';
			$this->thb_started_el = false;
		}

	}

	function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {

		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		$classes   = empty( $item->classes ) ? array() : (array) $item->classes;
		$classes[] = 'menu-item-' . $item->ID;

		$args        = apply_filters( 'nav_menu_item_args', $args, $item, $depth );
		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args, $depth ) );
		$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';
		$id          = apply_filters( 'nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args, $depth );

		$output .= $indent . '<li' . $class_names . '>';

		$atts = array();

		$atts['title']  = ! empty( $item->attr_title ) ? $item->attr_title : '';
		$atts['target'] = ! empty( $item->target ) ? $item->target : '';
		$atts['rel']    = ! empty( $item->xfn ) ? $item->xfn : '';
		$atts['href']   = ! empty( $item->url ) ? $item->url : '';
		$atts           = apply_filters( 'nav_menu_link_attributes', $atts, $item, $args, $depth );

		$attributes = '';
		foreach ( $atts as $attr => $value ) {
			if ( ! empty( $value ) ) {
				$value       = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
				$attributes .= ' ' . $attr . '="' . $value . '"';
			}
		}

		$title = apply_filters( 'the_title', $item->title, $item->ID );

		$title = apply_filters( 'nav_menu_item_title', $title, $item, $args, $depth );

		$item_output = $args->before;

		if ( $this->has_children && $depth == 0 ) {
			$item_output .= '<amp-accordion><section>';
			$item_output .= '<h6 class="thb-amphtml-accordion-header">';
			$item_output .= '<a' . $attributes . '>';
			$item_output .= $args->link_before . $title . $args->link_after;
			$item_output .= '</a>';
			$item_output .= '<span class="dropdown-toggle fa fa-plus"></span></h6>';

			$item_output               .= "\n<div>\n";
			$this->thb_started_el       = true;
			$this->thb_child_started_el = true;
		} else {
			$item_output .= '<a' . $attributes . '>';
			$item_output .= $args->link_before . $title . $args->link_after;
			$item_output .= '</a>';
		}

		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );

	}

	public function get_anchor_tag( $item, $depth, $args, $id ) {

		$current_el = '';

		parent::start_el( $current_el, $item, $depth, $args, $id );

		if ( preg_match( '#<\s*li\s* [^>]* > (.+) #ix', $current_el, $matched ) ) {
			return isset( $matched[1] ) ? $matched[1] : '';
		}

		return $this->thb_anchor_tag( $item, $args, $depth );
	}


	protected function thb_anchor_tag( $_item, $args, $depth ) {

		$atts           = array();
		$atts['title']  = ! empty( $_item->attr_title ) ? $_item->attr_title : '';
		$atts['target'] = ! empty( $_item->target ) ? $_item->target : '';
		$atts['rel']    = ! empty( $_item->xfn ) ? $_item->xfn : '';
		$atts['href']   = ! empty( $_item->url ) ? $_item->url : '';

		$atts = apply_filters( 'nav_menu_link_attributes', $atts, $_item, $args, $depth );

		$attributes = '';
		foreach ( $atts as $attr => $value ) {
			if ( ! empty( $value ) ) {
				$value       = ( 'href' === $attr ) ? esc_url( $value . $menu_anchor ) : esc_attr( $value );
				$attributes .= ' ' . $attr . '="' . $value . '"';
			}
		}

		$title = apply_filters( 'the_title', $_item->title, $_item->ID );
		$title = apply_filters( 'nav_menu_item_title', $title, $_item, $args, $depth );

		$_output  = $args->before;
		$_output .= '<a' . $attributes . '>';
		$_output .= $args->link_before . $title . $args->link_after;
		$_output .= '</a>';
		$_output .= $args->after;

		return $_output;
	}
}
