<?php
// De-register Contact Form 7 styles.
add_filter( 'wpcf7_load_js', '__return_false' );
add_filter( 'wpcf7_load_css', '__return_false' );

// Main Styles.
function thb_main_styles() {
	global $post;
	$i                       = 0;
	$self_hosted_fonts       = ot_get_option( 'self_hosted_fonts' );
	$thb_theme_directory_uri = Thb_Theme_Admin::$thb_theme_directory_uri;
	$thb_theme_version       = Thb_Theme_Admin::$thb_theme_version;

	// Enqueue.
	wp_enqueue_style( 'thb-fa', esc_url( $thb_theme_directory_uri ) . 'assets/css/font-awesome.min.css', null, '4.7.0' );
	wp_enqueue_style( 'thb-app', esc_url( $thb_theme_directory_uri ) . 'assets/css/app.css', null, esc_attr( $thb_theme_version ) );

	wp_dequeue_style( 'vc_lte_ie9' );
	wp_deregister_style( 'vc_lte_ie9' );

	if ( ! defined( 'THB_DEMO_SITE' ) ) {
		wp_enqueue_style( 'style', get_stylesheet_uri(), null, esc_attr( $thb_theme_version ) );
	}
	wp_enqueue_style( 'thb-google-fonts', thb_google_webfont(), null, esc_attr( $thb_theme_version ) );
	wp_add_inline_style( 'thb-app', thb_selection() );

	if ( $self_hosted_fonts ) {
		foreach ( $self_hosted_fonts as $font ) {
			$i++;
			wp_enqueue_style( 'thb-self-hosted-' . $i, $font['font_url'], null, esc_attr( $thb_theme_version ) );
		}
	}

	if ( $post ) {
		if ( has_shortcode( $post->post_content, 'contact-form-7' ) && function_exists( 'wpcf7_enqueue_styles' ) ) {
			wpcf7_enqueue_styles();
		}
	}
	// Remove Dynamic front-end CSS.
	remove_action( 'wp_enqueue_scripts', 'ot_load_dynamic_css', 999 );
}

add_action( 'wp_enqueue_scripts', 'thb_main_styles' );


// Main Scripts.
function thb_register_js() {

	if ( ! is_admin() ) {
		global $post;
		$thb_combined_libraries  = ot_get_option( 'thb_combined_libraries', 'on' );
		$thb_api_key             = ot_get_option( 'map_api_key' );
		$thb_dependency          = array( 'jquery', 'underscore' );
		$thb_theme_directory_uri = Thb_Theme_Admin::$thb_theme_directory_uri;
		$thb_theme_version       = Thb_Theme_Admin::$thb_theme_version;

		// Register.
		wp_register_script( 'gmapdep', 'https://maps.google.com/maps/api/js?key=' . esc_attr( $thb_api_key ), false, esc_attr( $thb_theme_version ), false );
		if ( 'on' === $thb_combined_libraries ) {
			wp_register_script( 'thb-vendor', esc_url( $thb_theme_directory_uri ) . 'assets/js/vendor.min.js', array( 'underscore', 'jquery' ), esc_attr( $thb_theme_version ), true );
			$thb_dependency[] = 'thb-vendor';
		} else {
			$thb_js_libraries = array(
				'GSAP'                      => '_0gsap.min.js',
				'GSAP-ScrollToPlugin'       => '_1ScrollToPlugin.min.js',
				'headroom'                  => 'headroom.min.js',
				'jquery-foundation-plugins' => 'jquery.foundation.plugins.js',
				'jquery-headroom'           => 'jQuery.headroom.js',
				'jquery-history'            => 'jquery.history.js',
				'jquery-magnific-popup'     => 'jquery.magnific-popup.min.js',
				'sticky-kit'                => 'jquery.sticky-kit.min.js',
				'js-cookie'                 => 'js.cookie.js',
				'lazysizes'                 => 'lazysizes.min.js',
				'mobile-detect'             => 'mobile-detect.min.js',
				'perfect-scrollbar'         => 'perfect-scrollbar.min.js',
				'plyr-polyfilled'           => 'plyr.polyfilled.min.js',
				'skrollr'                   => 'skrollr.min.js',
				'slick'                     => 'slick.min.js',
			);
			foreach ( $thb_js_libraries as $handle => $value ) {
				wp_enqueue_script( $handle, esc_url( $thb_theme_directory_uri ) . 'assets/js/vendor/' . esc_attr( $value ), array( 'jquery' ), esc_attr( $thb_theme_version ), true );
			}
		}
		if ( 'on' === ot_get_option( 'thb_custom_video_player', 'on' ) ) {
			wp_enqueue_script( 'plyr', 'https://cdn.plyr.io/3.6.3/plyr.polyfilled.js', array( 'jquery' ), '3.6.3', true );
		}

		wp_register_script( 'thb-app', esc_url( $thb_theme_directory_uri ) . 'assets/js/app.min.js', $thb_dependency, esc_attr( $thb_theme_version ), true );

		// Typekit.
		$typekit_id = ot_get_option( 'typekit_id' );
		if ( $typekit_id ) {
			wp_enqueue_script( 'thb-typekit', 'https://use.typekit.net/' . esc_attr( $typekit_id ) . '.js', false, esc_attr( $thb_theme_version ), false );
			wp_add_inline_script( 'thb-typekit', 'try{Typekit.load({ async: true });}catch(e){}' );
		}

		// Enqueue.
		if ( is_singular() && comments_open() && ( get_option( 'thread_comments' ) === 1 ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
		if ( $post ) {
			if ( has_shortcode( $post->post_content, 'thb_contactmap' ) ) {
				wp_enqueue_script( 'gmapdep' );
			}
			if ( has_shortcode( $post->post_content, 'contact-form-7' ) && function_exists( 'wpcf7_enqueue_scripts' ) ) {
				wpcf7_enqueue_scripts();
			}
		}
		wp_enqueue_script( 'thb-app' );
		wp_localize_script(
			'thb-app',
			'themeajax',
			array(
				'url'      => admin_url( 'admin-ajax.php' ),
				'l10n'     => array(
					'loading' => esc_html__( 'Loading ...', 'goodlife' ),
					'nomore'  => esc_html__( 'No More Posts', 'goodlife' ),
				),
				'settings' => array(
					'viai_publisher_id'       => ot_get_option( 'viai_publisher_id', '431861828953521' ),
					'thb_custom_video_player' => ot_get_option( 'thb_custom_video_player', 'on' ),
				),
			)
		);
	}
}
add_action( 'wp_enqueue_scripts', 'thb_register_js' );

// WooCommerce.
add_filter( 'woocommerce_enqueue_styles', '__return_false' );
