<?php
/* Category ID on Menu */
function thb_category_id_on_menu( $classes, $item ) {
	if ( $item->object !== 'category' ) {
		return $classes;
	}

	$classes[] = 'menu-item-category-' . $item->object_id;
	return $classes;
}
add_filter( 'nav_menu_css_class', 'thb_category_id_on_menu', 10, 2 );

/**
 * Custom Walker - Mobile Menu
 *
 * @access      public
 * @since       1.0
 * @return      void
 */
class thb_mobileDropdown extends Walker_Nav_Menu {

	function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		$class_names = '';

		$classes   = empty( $item->classes ) ? array() : (array) $item->classes;
		$classes[] = 'menu-item-' . $item->ID;

		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );
		$class_names = $class_names ? ' class=" ' . esc_attr( $class_names ) . '"' : '';

		$id = apply_filters( 'nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args );
		$id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

		$output .= $indent . '<li' . $id . $class_names . '>';

		$atts           = array();
		$atts['title']  = ! empty( $item->attr_title ) ? $item->attr_title : '';
		$atts['target'] = ! empty( $item->target ) ? $item->target : '';
		$atts['rel']    = ! empty( $item->xfn ) ? $item->xfn : '';
		$atts['href']   = ! empty( $item->url ) ? $item->url : '';

		$atts = apply_filters( 'nav_menu_link_attributes', $atts, $item, $args );

		$attributes = '';
		foreach ( $atts as $attr => $value ) {
			if ( ! empty( $value ) ) {
				$value       = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
				$attributes .= ' ' . $attr . '="' . $value . '"';
			}
		}
		$children = get_posts(
			array(
				'post_type'   => 'nav_menu_item',
				'nopaging'    => true,
				'numberposts' => 1,
				'meta_key'    => '_menu_item_menu_item_parent',
				'meta_value'  => $item->ID,
			)
		);

		$item_output   = $args->before;
		$dropdown_icon = ot_get_option( 'mobile_menu_style', 'style1' ) == 'style1' ? '<i class="fa fa-plus"></i></span>' : '<div></div><div></div>';
		$item_output  .= '<a' . $attributes . '>' . ( ! empty( $children ) ? '<span>' . $dropdown_icon . '</span>' : '' );

		/** This filter is documented in wp-includes/post-template.php */
		$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
		$item_output .= '</a>';
		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}
}

/**
 * Custom Walker
 *
 * @access      public
 * @since       1.0
 * @return      void
 */
class thb_MegaMenu extends Walker_Nav_Menu {

	var $active_megamenu = 0;

	/**
	 * @see Walker::start_lvl()
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param int    $depth Depth of page. Used for padding.
	 */
	function start_lvl( &$output, $depth = 0, $args = array() ) {
			$menubg_class = $args->menubg != '' ? 'has_bg' : '';
			$menubg_style = $args->menubg != '' ? 'style="background-image:url(' . $args->menubg . ');"' : '';

			$indent  = str_repeat( "\t", $depth );
			$output .= "\n$indent<ul class=\"sub-menu " . $menubg_class . '{locate_class}" ' . $menubg_style . ">\n";

	}

	/**
	 * @see Walker::end_lvl()
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param int    $depth Depth of page. Used for padding.
	 */
	function end_lvl( &$output, $depth = 0, $args = array() ) {
			$indent  = str_repeat( "\t", $depth );
			$output .= "$indent</ul>\n";

		if ( $this->active_megamenu && $depth === 1 ) {
				$output = str_replace( '{locate_class}', ' thb_mega_menu', $output );
		} else {
				$output = str_replace( '{locate_class}', '', $output );
		}
	}

	function start_el( &$output, $item, $depth = 0, $args = array(), $current_object_id = 0 ) {
			$item_output = $column_class = '';

			$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

			$classes   = empty( $item->classes ) ? array() : (array) $item->classes;
			$classes[] = 'menu-item-' . $item->ID;

			/**
			 * Filter the CSS class(es) applied to a menu item's list item element.
			 *
			 * @since 3.0.0
			 * @since 4.1.0 The `$depth` parameter was added.
			 *
			 * @param array  $classes The CSS classes that are applied to the menu item's `<li>` element.
			 * @param object $item    The current menu item.
			 * @param array  $args    An array of {@see wp_nav_menu()} arguments.
			 * @param int    $depth   Depth of menu item. Used for padding.
			 */
			$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args, $depth ) );

		if ( $depth === 0 ) {
			$this->active_megamenu = get_post_meta( $item->ID, '_menu_item_megamenu', true );
			if ( $this->active_megamenu ) {
				$class_names .= ' menu-item-mega-parent '; }
		}
		if ( $depth === 1 ) {
			if ( $this->active_megamenu ) {
				$class_names .= ' menu-item-mega-child '; }
		}
		if ( $depth === 2 ) {
			if ( $this->active_megamenu ) {
				$class_names .= ' menu-item-mega-link '; }
		}

			$title = apply_filters( 'the_title', $item->title, $item->ID );

		if ( $title != '-' && $title != '"-"' ) {

				$atts           = array();
				$atts['title']  = ! empty( $item->attr_title ) ? $item->attr_title : '';
				$atts['target'] = ! empty( $item->target ) ? $item->target : '';
				$atts['rel']    = ! empty( $item->xfn ) ? $item->xfn : '';
				$atts['href']   = ! empty( $item->url ) ? $item->url : '';
				$menu_icon_tag  = ! empty( $item->menuicon ) ? '<i class="fa ' . esc_attr( $item->menuicon ) . '"></i>' : '';
				$menu_anchor    = ! empty( $item->menuanchor ) ? '#' . esc_attr( $item->menuanchor ) : '';
				$menu_bg        = ! empty( $item->menubg ) ? '#' . esc_attr( $item->menubg ) : '';

				$atts = apply_filters( 'nav_menu_link_attributes', $atts, $item, $args, $depth );

				$attributes = '';
			foreach ( $atts as $attr => $value ) {
				if ( ! empty( $value ) ) {
					$value       = ( 'href' === $attr ) ? esc_url( $value . $menu_anchor ) : esc_attr( $value );
					$attributes .= ' ' . $attr . '="' . $value . '"';
				}
			}

				$item_output = $args->before;
			if ( $depth === 1 && $this->active_megamenu ) {
				$item_output .= '<div class="megamenu-title">';
			}
				$item_output .= '<a' . $attributes . '>';
				/** This filter is documented in wp-includes/post-template.php */
				$item_output .= $menu_icon_tag;
				$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
				$item_output .= '</a>';
			if ( $depth === 1 && $this->active_megamenu ) {
				$item_output .= '</div>';
			}
				$item_output .= $args->after;
		}

			$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

			$output .= $indent . '<li id="menu-item-' . $item->ID . '"' . $class_names . '>';
			$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );

			apply_filters( 'walker_nav_menu_start_lvl', $item_output, $depth, $args->menubg = $item->menubg );
	}
}

/**
 * Custom Walker
 *
 * @access      public
 * @since       1.0
 * @return      void
 */
class thb_MegaMenu_tagandcat_Walker extends Walker_Nav_Menu {
	private $in_sub_menu = 0;
	var $active_megamenu = 0;
	var $mega_menu_content;

	var $mega_menu_style;

	function __construct() {
		$this->mega_menu_style = ot_get_option( 'mega_menu_style', 'style1' );
	}
	/**
	 * @see Walker::start_lvl()
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param int    $depth Depth of page. Used for padding.
	 */
	function start_lvl( &$output, $depth = 0, $args = array() ) {
		$indent = str_repeat( "\t", $depth );
		if ( $depth === 0 ) {
			$output .= "\n{replace_one}\n";
		}
		$output .= "\n$indent<ul class=\"sub-menu " . ( ( $depth === 0 ) ? '{locate_class}' : '' ) . "\">\n";
	}

	/**
	 * @see Walker::end_lvl()
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param int    $depth Depth of page. Used for padding.
	 */
	function end_lvl( &$output, $depth = 0, $args = array() ) {
		$indent  = str_repeat( "\t", $depth );
		$output .= "$indent</ul>\n";
		if ( $depth === 0 && $this->active_megamenu ) {
			$output .= '<div class="category-children cf">' . $this->mega_menu_content . '</div></div></div></div>';

		}
		if ( $depth === 0 ) {
			if ( $this->active_megamenu ) {
				$output = str_replace( '{replace_one}', '<div class="thb_mega_menu_holder ' . esc_attr( $this->mega_menu_style ) . '"><div class="row"><div class="small-12 columns">', $output );
				$output = str_replace( '{locate_class}', 'thb_mega_menu', $output );
			} else {
				$output = str_replace( '{locate_class}', '', $output );
				$output = str_replace( '{replace_one}', '', $output );
			}
		}
		$this->mega_menu_content = '';
	}
	function start_el( &$output, $item, $depth = 0, $args = array(), $current_object_id = 0 ) {
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		$classes   = empty( $item->classes ) ? array() : (array) $item->classes;
		$classes[] = 'menu-item-' . $item->ID;

		if ( $depth == 1 ) {
			if ( ! $this->in_sub_menu ) {
					$this->in_sub_menu = 1;
					array_push( $classes, 'active' );
			}
		}
		if ( $depth == 0 ) {
				$this->in_sub_menu     = 0;
				$this->active_megamenu = get_post_meta( $item->ID, '_menu_item_megamenu', true );
		}

		if ( $depth === 0 && $this->active_megamenu ) {
			 array_push( $classes, 'menu-item-mega-parent' );
		}

		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args, $depth ) );
		$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';

		$id = apply_filters( 'nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args, $depth );
		$id = $id ? ' id="' . esc_attr( $id ) . '"' : '';

		$output .= $indent . '<li' . $id . $class_names . '>';

			$atts          = array();
			$menu_icon_tag = ! empty( $item->menuicon ) ? '<i class="fa ' . esc_attr( $item->menuicon ) . '"></i>' : '';
		$atts['title']     = ! empty( $item->attr_title ) ? $item->attr_title : '';
		$atts['target']    = ! empty( $item->target ) ? $item->target : '';
		$atts['rel']       = ! empty( $item->xfn ) ? $item->xfn : '';
		$atts['href']      = ! empty( $item->url ) ? $item->url : '';

			$atts = apply_filters( 'nav_menu_link_attributes', $atts, $item, $args, $depth );

		$attributes = '';
		foreach ( $atts as $attr => $value ) {
			if ( ! empty( $value ) ) {
				$value       = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
				$attributes .= ' ' . $attr . '="' . $value . '"';
			}
		}

		$item_output  = $args->before;
		$item_output .= '<a' . $attributes . '>';
		if ( $depth == 1 && $this->active_megamenu ) {
		} else {
				$this->in_sub_menu = 1;
		}
		$item_output .= $menu_icon_tag;
		$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
		$item_output .= '</a>';
		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}
	public function end_el( &$output, $item, $depth = 0, $args = array() ) {
		if ( $depth == 1 && $this->in_sub_menu ) {
			$ppp   = $this->mega_menu_style == 'style1' ? 3 : 4;
			$class = $this->mega_menu_style == 'style1' ? 'large-4' : 'large-3';
			if ( in_array( $item->object, array( 'post_tag', 'category', 'product_cat', 'product_tag', 'post_format' ) ) ) {
				if ( $item->object == 'post_tag' ) {
					$args = array(
						'tag_id'         => $item->object_id,
						'posts_per_page' => $ppp,
						'no_found_rows'  => true,
					);
				} elseif ( $item->object == 'category' ) {
					$args = array(
						'cat'            => $item->object_id,
						'posts_per_page' => $ppp,
						'no_found_rows'  => true,
					);
				} elseif ( $item->object == 'product_cat' ) {
					$cat  = get_term( $item->object_id, 'product_cat' );
					$args = array(
						'post_type'      => 'product',
						'post_status'    => 'publish',
						'product_cat'    => $cat->slug,
						'posts_per_page' => $ppp,
						'no_found_rows'  => true,
					);
				} elseif ( $item->object == 'product_tag' ) {
					$tag  = get_term( $item->object_id, 'product_tag' );
					$args = array(
						'post_type'      => 'product',
						'post_status'    => 'publish',
						'product_tag'    => $tag->slug,
						'posts_per_page' => $ppp,
						'no_found_rows'  => true,
					);

				} elseif ( $item->object == 'post_format' ) {
					$format = get_term( $item->object_id, 'post_format' );
					$args   = array(
						'posts_per_page' => $ppp,
						'tax_query'      => array(
							array(
								'taxonomy' => 'post_format',
								'field'    => 'slug',
								'terms'    => array( $format->slug ),
								'operator' => 'IN',
							),
						),
						'no_found_rows'  => true,
					);

				}
				$is_product_related = in_array( $item->object, array( 'product_cat', 'product_tag' ) );

				ob_start();
				$query = new WP_Query( $args );
				echo '<div class="row ' . ( $is_product_related ? 'products' : '' ) . '">';
				if ( $query->have_posts() ) {
					while ( $query->have_posts() ) :
						$query->the_post();
						echo '<div class="small-12 medium-6 ' . esc_attr( $class ) . ' columns">';
						if ( $is_product_related ) {
							wc_get_template_part( 'content', 'product-menu' );
						} elseif ( ot_get_option( 'megamenu_categories', 'off' ) === 'off' ) {
							get_template_part( 'inc/templates/post-styles/style1-meta-nocat' );
						} else {
							get_template_part( 'inc/templates/post-styles/style1-meta' );
						}
						echo '</div>';
					endwhile;
				}
				echo '</div>';
				$html = ob_get_clean();
				wp_reset_query();
				wp_reset_postdata();
				$this->mega_menu_content .= $html;

			}
		}
		$output .= "</li>\n";
	}
}

/* Custom Menu Fields */
$GLOBALS['thb_custom_menu'] = new rc_thb_custom_menu();

class rc_thb_custom_menu {

		/*
		--------------------------------------------*
		 * Constructor
		 *--------------------------------------------*/

		/**
		 * Initializes the plugin by setting localization, filters, and administration functions.
		 */
	function __construct() {

			// add custom menu fields to menu
			add_filter( 'wp_setup_nav_menu_item', array( $this, 'rc_scm_add_custom_nav_fields' ) );

			// save menu custom fields
			add_action( 'wp_update_nav_menu_item', array( $this, 'rc_scm_update_custom_nav_fields' ), 10, 3 );

	} // end constructor


		/**
		 * Add custom fields to $item nav object
		 * in order to be used in custom Walker
		 *
		 * @access      public
		 * @since       1.0
		 * @return      void
		 */
	function rc_scm_add_custom_nav_fields( $menu_item ) {

			$menu_item->menuicon   = get_post_meta( $menu_item->ID, '_menu_item_menuicon', true );
			$menu_item->menuanchor = get_post_meta( $menu_item->ID, '_menu_item_menuanchor', true );
			$menu_item->menubg     = get_post_meta( $menu_item->ID, '_menu_item_menubg', true );
			$menu_item->megamenu   = get_post_meta( $menu_item->ID, '_menu_item_megamenu', true );
			return $menu_item;

	}

		/**
		 * Save menu custom fields
		 *
		 * @access      public
		 * @since       1.0
		 * @return      void
		 */
	function rc_scm_update_custom_nav_fields( $menu_id, $menu_item_db_id, $args ) {

			// Check if element is properly sent

		if ( ! empty( $_REQUEST['edit-menu-item-menuicon'] ) && is_array( $_REQUEST['edit-menu-item-menuicon'] ) ) {
				$menu_icon_value = $_REQUEST['edit-menu-item-menuicon'][ $menu_item_db_id ];
				update_post_meta( $menu_item_db_id, '_menu_item_menuicon', $menu_icon_value );
		}
		if ( ! empty( $_REQUEST['edit-menu-item-menubg'][ $menu_item_db_id ] ) ) {
				$menu_bg_value = $_REQUEST['edit-menu-item-menubg'][ $menu_item_db_id ];
				update_post_meta( $menu_item_db_id, '_menu_item_menubg', $menu_bg_value );
		}

		if ( ! empty( $_REQUEST['edit-menu-item-menuanchor'][ $menu_item_db_id ] ) ) {
				$menu_anchor_value = $_REQUEST['edit-menu-item-menuanchor'][ $menu_item_db_id ];
				update_post_meta( $menu_item_db_id, '_menu_item_menuanchor', $menu_anchor_value );
		}

		if ( ! isset( $_REQUEST['edit-menu-item-megamenu'][ $menu_item_db_id ] ) ) {
				$_REQUEST['edit-menu-item-megamenu'][ $menu_item_db_id ] = '';
		}
			$menu_mega_enabled_value = $_REQUEST['edit-menu-item-megamenu'][ $menu_item_db_id ];
			update_post_meta( $menu_item_db_id, '_menu_item_megamenu', $menu_mega_enabled_value );
	}

}

function thb_custom_nav_fields_action( $item_id, $item, $depth, $args, $id ) {
	$thb_icons = thb_getIconArray();
	?>
	<div class="thb_menu_options">
		<h2><?php esc_html_e( 'Fuel Themes Menu Options', 'goodlife' ); ?></h2>
		<div class="thb-field-link description description-thin">
			<h3><?php esc_html_e( 'Menu Item Icon', 'goodlife' ); ?></h3>
			<?php $saved = get_post_meta( $item_id, '_menu_item_menuicon', true ); ?>
			<select id="edit-menu-item-menuicon-<?php echo esc_attr( $item_id ); ?>" name="edit-menu-item-menuicon[<?php echo esc_attr( $item_id ); ?>]">

				<?php foreach ( $thb_icons as $key => $value ) { ?>
					<option value="<?php echo esc_attr( $key ); ?>" <?php selected( $key, $saved ); ?>><?php echo esc_html( $value ); ?></option>
				<?php } ?>
			</select>
		</div>
		<div class="thb-field-link-mega description description-thin">
			<h3><?php esc_html_e( 'Mega Menu', 'goodlife' ); ?></h3>
				<?php $value = get_post_meta( $item_id, '_menu_item_megamenu', true ); ?>
				<label for="edit-menu-item-megamenu-<?php echo esc_attr( $item_id ); ?>">
						<input type="checkbox" value="enabled" id="edit-menu-item-megamenu-<?php echo esc_attr( $item_id ); ?>" name="edit-menu-item-megamenu[<?php echo esc_attr( $item_id ); ?>]" <?php checked( $value, 'enabled' ); ?> />
						<?php esc_html_e( 'Enable', 'goodlife' ); ?>
				</label>
		</div>
	</div>
	<?php
}
add_action( 'wp_nav_menu_item_custom_fields', 'thb_custom_nav_fields_action', 10, 5 );
